from counterweight.styles import Margin, Style
from counterweight.styles.styles import Border, BorderEdge, BorderKind, CellStyle, Color, Flex, Padding, Typography

# Start generated

text_white = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ffffff"))))
text_black = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#000000"))))

slate_50 = Color.from_hex("#f8fafc")
text_slate_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f8fafc"))))
text_bg_slate_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f8fafc"))))
border_slate_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f8fafc"))))
border_bg_slate_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f8fafc"))))
margin_slate_50 = Style(margin=Margin(color=Color.from_hex("#f8fafc")))
padding_slate_50 = Style(padding=Padding(color=Color.from_hex("#f8fafc")))
slate_100 = Color.from_hex("#f1f5f9")
text_slate_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f1f5f9"))))
text_bg_slate_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f1f5f9"))))
border_slate_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f1f5f9"))))
border_bg_slate_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f1f5f9"))))
margin_slate_100 = Style(margin=Margin(color=Color.from_hex("#f1f5f9")))
padding_slate_100 = Style(padding=Padding(color=Color.from_hex("#f1f5f9")))
slate_200 = Color.from_hex("#e2e8f0")
text_slate_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e2e8f0"))))
text_bg_slate_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e2e8f0"))))
border_slate_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e2e8f0"))))
border_bg_slate_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e2e8f0"))))
margin_slate_200 = Style(margin=Margin(color=Color.from_hex("#e2e8f0")))
padding_slate_200 = Style(padding=Padding(color=Color.from_hex("#e2e8f0")))
slate_300 = Color.from_hex("#cbd5e1")
text_slate_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#cbd5e1"))))
text_bg_slate_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#cbd5e1"))))
border_slate_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#cbd5e1"))))
border_bg_slate_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#cbd5e1"))))
margin_slate_300 = Style(margin=Margin(color=Color.from_hex("#cbd5e1")))
padding_slate_300 = Style(padding=Padding(color=Color.from_hex("#cbd5e1")))
slate_400 = Color.from_hex("#94a3b8")
text_slate_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#94a3b8"))))
text_bg_slate_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#94a3b8"))))
border_slate_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#94a3b8"))))
border_bg_slate_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#94a3b8"))))
margin_slate_400 = Style(margin=Margin(color=Color.from_hex("#94a3b8")))
padding_slate_400 = Style(padding=Padding(color=Color.from_hex("#94a3b8")))
slate_500 = Color.from_hex("#64748b")
text_slate_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#64748b"))))
text_bg_slate_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#64748b"))))
border_slate_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#64748b"))))
border_bg_slate_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#64748b"))))
margin_slate_500 = Style(margin=Margin(color=Color.from_hex("#64748b")))
padding_slate_500 = Style(padding=Padding(color=Color.from_hex("#64748b")))
slate_600 = Color.from_hex("#475569")
text_slate_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#475569"))))
text_bg_slate_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#475569"))))
border_slate_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#475569"))))
border_bg_slate_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#475569"))))
margin_slate_600 = Style(margin=Margin(color=Color.from_hex("#475569")))
padding_slate_600 = Style(padding=Padding(color=Color.from_hex("#475569")))
slate_700 = Color.from_hex("#334155")
text_slate_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#334155"))))
text_bg_slate_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#334155"))))
border_slate_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#334155"))))
border_bg_slate_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#334155"))))
margin_slate_700 = Style(margin=Margin(color=Color.from_hex("#334155")))
padding_slate_700 = Style(padding=Padding(color=Color.from_hex("#334155")))
slate_800 = Color.from_hex("#1e293b")
text_slate_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1e293b"))))
text_bg_slate_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1e293b"))))
border_slate_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1e293b"))))
border_bg_slate_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1e293b"))))
margin_slate_800 = Style(margin=Margin(color=Color.from_hex("#1e293b")))
padding_slate_800 = Style(padding=Padding(color=Color.from_hex("#1e293b")))
slate_900 = Color.from_hex("#0f172a")
text_slate_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0f172a"))))
text_bg_slate_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0f172a"))))
border_slate_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0f172a"))))
border_bg_slate_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0f172a"))))
margin_slate_900 = Style(margin=Margin(color=Color.from_hex("#0f172a")))
padding_slate_900 = Style(padding=Padding(color=Color.from_hex("#0f172a")))
slate_950 = Color.from_hex("#020617")
text_slate_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#020617"))))
text_bg_slate_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#020617"))))
border_slate_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#020617"))))
border_bg_slate_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#020617"))))
margin_slate_950 = Style(margin=Margin(color=Color.from_hex("#020617")))
padding_slate_950 = Style(padding=Padding(color=Color.from_hex("#020617")))

gray_50 = Color.from_hex("#f9fafb")
text_gray_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f9fafb"))))
text_bg_gray_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f9fafb"))))
border_gray_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f9fafb"))))
border_bg_gray_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f9fafb"))))
margin_gray_50 = Style(margin=Margin(color=Color.from_hex("#f9fafb")))
padding_gray_50 = Style(padding=Padding(color=Color.from_hex("#f9fafb")))
gray_100 = Color.from_hex("#f3f4f6")
text_gray_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f3f4f6"))))
text_bg_gray_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f3f4f6"))))
border_gray_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f3f4f6"))))
border_bg_gray_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f3f4f6"))))
margin_gray_100 = Style(margin=Margin(color=Color.from_hex("#f3f4f6")))
padding_gray_100 = Style(padding=Padding(color=Color.from_hex("#f3f4f6")))
gray_200 = Color.from_hex("#e5e7eb")
text_gray_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e5e7eb"))))
text_bg_gray_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e5e7eb"))))
border_gray_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e5e7eb"))))
border_bg_gray_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e5e7eb"))))
margin_gray_200 = Style(margin=Margin(color=Color.from_hex("#e5e7eb")))
padding_gray_200 = Style(padding=Padding(color=Color.from_hex("#e5e7eb")))
gray_300 = Color.from_hex("#d1d5db")
text_gray_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d1d5db"))))
text_bg_gray_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d1d5db"))))
border_gray_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d1d5db"))))
border_bg_gray_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d1d5db"))))
margin_gray_300 = Style(margin=Margin(color=Color.from_hex("#d1d5db")))
padding_gray_300 = Style(padding=Padding(color=Color.from_hex("#d1d5db")))
gray_400 = Color.from_hex("#9ca3af")
text_gray_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#9ca3af"))))
text_bg_gray_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#9ca3af"))))
border_gray_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#9ca3af"))))
border_bg_gray_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#9ca3af"))))
margin_gray_400 = Style(margin=Margin(color=Color.from_hex("#9ca3af")))
padding_gray_400 = Style(padding=Padding(color=Color.from_hex("#9ca3af")))
gray_500 = Color.from_hex("#6b7280")
text_gray_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#6b7280"))))
text_bg_gray_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#6b7280"))))
border_gray_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#6b7280"))))
border_bg_gray_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#6b7280"))))
margin_gray_500 = Style(margin=Margin(color=Color.from_hex("#6b7280")))
padding_gray_500 = Style(padding=Padding(color=Color.from_hex("#6b7280")))
gray_600 = Color.from_hex("#4b5563")
text_gray_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4b5563"))))
text_bg_gray_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4b5563"))))
border_gray_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4b5563"))))
border_bg_gray_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4b5563"))))
margin_gray_600 = Style(margin=Margin(color=Color.from_hex("#4b5563")))
padding_gray_600 = Style(padding=Padding(color=Color.from_hex("#4b5563")))
gray_700 = Color.from_hex("#374151")
text_gray_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#374151"))))
text_bg_gray_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#374151"))))
border_gray_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#374151"))))
border_bg_gray_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#374151"))))
margin_gray_700 = Style(margin=Margin(color=Color.from_hex("#374151")))
padding_gray_700 = Style(padding=Padding(color=Color.from_hex("#374151")))
gray_800 = Color.from_hex("#1f2937")
text_gray_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1f2937"))))
text_bg_gray_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1f2937"))))
border_gray_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1f2937"))))
border_bg_gray_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1f2937"))))
margin_gray_800 = Style(margin=Margin(color=Color.from_hex("#1f2937")))
padding_gray_800 = Style(padding=Padding(color=Color.from_hex("#1f2937")))
gray_900 = Color.from_hex("#111827")
text_gray_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#111827"))))
text_bg_gray_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#111827"))))
border_gray_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#111827"))))
border_bg_gray_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#111827"))))
margin_gray_900 = Style(margin=Margin(color=Color.from_hex("#111827")))
padding_gray_900 = Style(padding=Padding(color=Color.from_hex("#111827")))
gray_950 = Color.from_hex("#030712")
text_gray_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#030712"))))
text_bg_gray_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#030712"))))
border_gray_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#030712"))))
border_bg_gray_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#030712"))))
margin_gray_950 = Style(margin=Margin(color=Color.from_hex("#030712")))
padding_gray_950 = Style(padding=Padding(color=Color.from_hex("#030712")))

zinc_50 = Color.from_hex("#fafafa")
text_zinc_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fafafa"))))
text_bg_zinc_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fafafa"))))
border_zinc_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fafafa"))))
border_bg_zinc_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fafafa"))))
margin_zinc_50 = Style(margin=Margin(color=Color.from_hex("#fafafa")))
padding_zinc_50 = Style(padding=Padding(color=Color.from_hex("#fafafa")))
zinc_100 = Color.from_hex("#f4f4f5")
text_zinc_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f4f4f5"))))
text_bg_zinc_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f4f4f5"))))
border_zinc_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f4f4f5"))))
border_bg_zinc_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f4f4f5"))))
margin_zinc_100 = Style(margin=Margin(color=Color.from_hex("#f4f4f5")))
padding_zinc_100 = Style(padding=Padding(color=Color.from_hex("#f4f4f5")))
zinc_200 = Color.from_hex("#e4e4e7")
text_zinc_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e4e4e7"))))
text_bg_zinc_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e4e4e7"))))
border_zinc_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e4e4e7"))))
border_bg_zinc_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e4e4e7"))))
margin_zinc_200 = Style(margin=Margin(color=Color.from_hex("#e4e4e7")))
padding_zinc_200 = Style(padding=Padding(color=Color.from_hex("#e4e4e7")))
zinc_300 = Color.from_hex("#d4d4d8")
text_zinc_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d4d4d8"))))
text_bg_zinc_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d4d4d8"))))
border_zinc_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d4d4d8"))))
border_bg_zinc_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d4d4d8"))))
margin_zinc_300 = Style(margin=Margin(color=Color.from_hex("#d4d4d8")))
padding_zinc_300 = Style(padding=Padding(color=Color.from_hex("#d4d4d8")))
zinc_400 = Color.from_hex("#a1a1aa")
text_zinc_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a1a1aa"))))
text_bg_zinc_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a1a1aa"))))
border_zinc_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a1a1aa"))))
border_bg_zinc_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a1a1aa"))))
margin_zinc_400 = Style(margin=Margin(color=Color.from_hex("#a1a1aa")))
padding_zinc_400 = Style(padding=Padding(color=Color.from_hex("#a1a1aa")))
zinc_500 = Color.from_hex("#71717a")
text_zinc_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#71717a"))))
text_bg_zinc_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#71717a"))))
border_zinc_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#71717a"))))
border_bg_zinc_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#71717a"))))
margin_zinc_500 = Style(margin=Margin(color=Color.from_hex("#71717a")))
padding_zinc_500 = Style(padding=Padding(color=Color.from_hex("#71717a")))
zinc_600 = Color.from_hex("#52525b")
text_zinc_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#52525b"))))
text_bg_zinc_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#52525b"))))
border_zinc_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#52525b"))))
border_bg_zinc_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#52525b"))))
margin_zinc_600 = Style(margin=Margin(color=Color.from_hex("#52525b")))
padding_zinc_600 = Style(padding=Padding(color=Color.from_hex("#52525b")))
zinc_700 = Color.from_hex("#3f3f46")
text_zinc_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#3f3f46"))))
text_bg_zinc_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#3f3f46"))))
border_zinc_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#3f3f46"))))
border_bg_zinc_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#3f3f46"))))
margin_zinc_700 = Style(margin=Margin(color=Color.from_hex("#3f3f46")))
padding_zinc_700 = Style(padding=Padding(color=Color.from_hex("#3f3f46")))
zinc_800 = Color.from_hex("#27272a")
text_zinc_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#27272a"))))
text_bg_zinc_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#27272a"))))
border_zinc_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#27272a"))))
border_bg_zinc_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#27272a"))))
margin_zinc_800 = Style(margin=Margin(color=Color.from_hex("#27272a")))
padding_zinc_800 = Style(padding=Padding(color=Color.from_hex("#27272a")))
zinc_900 = Color.from_hex("#18181b")
text_zinc_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#18181b"))))
text_bg_zinc_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#18181b"))))
border_zinc_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#18181b"))))
border_bg_zinc_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#18181b"))))
margin_zinc_900 = Style(margin=Margin(color=Color.from_hex("#18181b")))
padding_zinc_900 = Style(padding=Padding(color=Color.from_hex("#18181b")))
zinc_950 = Color.from_hex("#09090b")
text_zinc_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#09090b"))))
text_bg_zinc_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#09090b"))))
border_zinc_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#09090b"))))
border_bg_zinc_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#09090b"))))
margin_zinc_950 = Style(margin=Margin(color=Color.from_hex("#09090b")))
padding_zinc_950 = Style(padding=Padding(color=Color.from_hex("#09090b")))

neutral_50 = Color.from_hex("#fafafa")
text_neutral_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fafafa"))))
text_bg_neutral_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fafafa"))))
border_neutral_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fafafa"))))
border_bg_neutral_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fafafa"))))
margin_neutral_50 = Style(margin=Margin(color=Color.from_hex("#fafafa")))
padding_neutral_50 = Style(padding=Padding(color=Color.from_hex("#fafafa")))
neutral_100 = Color.from_hex("#f5f5f5")
text_neutral_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f5f5f5"))))
text_bg_neutral_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f5f5f5"))))
border_neutral_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f5f5f5"))))
border_bg_neutral_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f5f5f5"))))
margin_neutral_100 = Style(margin=Margin(color=Color.from_hex("#f5f5f5")))
padding_neutral_100 = Style(padding=Padding(color=Color.from_hex("#f5f5f5")))
neutral_200 = Color.from_hex("#e5e5e5")
text_neutral_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e5e5e5"))))
text_bg_neutral_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e5e5e5"))))
border_neutral_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e5e5e5"))))
border_bg_neutral_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e5e5e5"))))
margin_neutral_200 = Style(margin=Margin(color=Color.from_hex("#e5e5e5")))
padding_neutral_200 = Style(padding=Padding(color=Color.from_hex("#e5e5e5")))
neutral_300 = Color.from_hex("#d4d4d4")
text_neutral_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d4d4d4"))))
text_bg_neutral_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d4d4d4"))))
border_neutral_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d4d4d4"))))
border_bg_neutral_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d4d4d4"))))
margin_neutral_300 = Style(margin=Margin(color=Color.from_hex("#d4d4d4")))
padding_neutral_300 = Style(padding=Padding(color=Color.from_hex("#d4d4d4")))
neutral_400 = Color.from_hex("#a3a3a3")
text_neutral_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a3a3a3"))))
text_bg_neutral_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a3a3a3"))))
border_neutral_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a3a3a3"))))
border_bg_neutral_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a3a3a3"))))
margin_neutral_400 = Style(margin=Margin(color=Color.from_hex("#a3a3a3")))
padding_neutral_400 = Style(padding=Padding(color=Color.from_hex("#a3a3a3")))
neutral_500 = Color.from_hex("#737373")
text_neutral_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#737373"))))
text_bg_neutral_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#737373"))))
border_neutral_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#737373"))))
border_bg_neutral_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#737373"))))
margin_neutral_500 = Style(margin=Margin(color=Color.from_hex("#737373")))
padding_neutral_500 = Style(padding=Padding(color=Color.from_hex("#737373")))
neutral_600 = Color.from_hex("#525252")
text_neutral_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#525252"))))
text_bg_neutral_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#525252"))))
border_neutral_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#525252"))))
border_bg_neutral_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#525252"))))
margin_neutral_600 = Style(margin=Margin(color=Color.from_hex("#525252")))
padding_neutral_600 = Style(padding=Padding(color=Color.from_hex("#525252")))
neutral_700 = Color.from_hex("#404040")
text_neutral_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#404040"))))
text_bg_neutral_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#404040"))))
border_neutral_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#404040"))))
border_bg_neutral_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#404040"))))
margin_neutral_700 = Style(margin=Margin(color=Color.from_hex("#404040")))
padding_neutral_700 = Style(padding=Padding(color=Color.from_hex("#404040")))
neutral_800 = Color.from_hex("#262626")
text_neutral_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#262626"))))
text_bg_neutral_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#262626"))))
border_neutral_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#262626"))))
border_bg_neutral_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#262626"))))
margin_neutral_800 = Style(margin=Margin(color=Color.from_hex("#262626")))
padding_neutral_800 = Style(padding=Padding(color=Color.from_hex("#262626")))
neutral_900 = Color.from_hex("#171717")
text_neutral_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#171717"))))
text_bg_neutral_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#171717"))))
border_neutral_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#171717"))))
border_bg_neutral_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#171717"))))
margin_neutral_900 = Style(margin=Margin(color=Color.from_hex("#171717")))
padding_neutral_900 = Style(padding=Padding(color=Color.from_hex("#171717")))
neutral_950 = Color.from_hex("#0a0a0a")
text_neutral_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0a0a0a"))))
text_bg_neutral_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0a0a0a"))))
border_neutral_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0a0a0a"))))
border_bg_neutral_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0a0a0a"))))
margin_neutral_950 = Style(margin=Margin(color=Color.from_hex("#0a0a0a")))
padding_neutral_950 = Style(padding=Padding(color=Color.from_hex("#0a0a0a")))

stone_50 = Color.from_hex("#fafaf9")
text_stone_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fafaf9"))))
text_bg_stone_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fafaf9"))))
border_stone_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fafaf9"))))
border_bg_stone_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fafaf9"))))
margin_stone_50 = Style(margin=Margin(color=Color.from_hex("#fafaf9")))
padding_stone_50 = Style(padding=Padding(color=Color.from_hex("#fafaf9")))
stone_100 = Color.from_hex("#f5f5f4")
text_stone_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f5f5f4"))))
text_bg_stone_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f5f5f4"))))
border_stone_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f5f5f4"))))
border_bg_stone_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f5f5f4"))))
margin_stone_100 = Style(margin=Margin(color=Color.from_hex("#f5f5f4")))
padding_stone_100 = Style(padding=Padding(color=Color.from_hex("#f5f5f4")))
stone_200 = Color.from_hex("#e7e5e4")
text_stone_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e7e5e4"))))
text_bg_stone_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e7e5e4"))))
border_stone_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e7e5e4"))))
border_bg_stone_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e7e5e4"))))
margin_stone_200 = Style(margin=Margin(color=Color.from_hex("#e7e5e4")))
padding_stone_200 = Style(padding=Padding(color=Color.from_hex("#e7e5e4")))
stone_300 = Color.from_hex("#d6d3d1")
text_stone_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d6d3d1"))))
text_bg_stone_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d6d3d1"))))
border_stone_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d6d3d1"))))
border_bg_stone_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d6d3d1"))))
margin_stone_300 = Style(margin=Margin(color=Color.from_hex("#d6d3d1")))
padding_stone_300 = Style(padding=Padding(color=Color.from_hex("#d6d3d1")))
stone_400 = Color.from_hex("#a8a29e")
text_stone_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a8a29e"))))
text_bg_stone_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a8a29e"))))
border_stone_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a8a29e"))))
border_bg_stone_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a8a29e"))))
margin_stone_400 = Style(margin=Margin(color=Color.from_hex("#a8a29e")))
padding_stone_400 = Style(padding=Padding(color=Color.from_hex("#a8a29e")))
stone_500 = Color.from_hex("#78716c")
text_stone_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#78716c"))))
text_bg_stone_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#78716c"))))
border_stone_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#78716c"))))
border_bg_stone_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#78716c"))))
margin_stone_500 = Style(margin=Margin(color=Color.from_hex("#78716c")))
padding_stone_500 = Style(padding=Padding(color=Color.from_hex("#78716c")))
stone_600 = Color.from_hex("#57534e")
text_stone_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#57534e"))))
text_bg_stone_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#57534e"))))
border_stone_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#57534e"))))
border_bg_stone_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#57534e"))))
margin_stone_600 = Style(margin=Margin(color=Color.from_hex("#57534e")))
padding_stone_600 = Style(padding=Padding(color=Color.from_hex("#57534e")))
stone_700 = Color.from_hex("#44403c")
text_stone_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#44403c"))))
text_bg_stone_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#44403c"))))
border_stone_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#44403c"))))
border_bg_stone_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#44403c"))))
margin_stone_700 = Style(margin=Margin(color=Color.from_hex("#44403c")))
padding_stone_700 = Style(padding=Padding(color=Color.from_hex("#44403c")))
stone_800 = Color.from_hex("#292524")
text_stone_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#292524"))))
text_bg_stone_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#292524"))))
border_stone_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#292524"))))
border_bg_stone_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#292524"))))
margin_stone_800 = Style(margin=Margin(color=Color.from_hex("#292524")))
padding_stone_800 = Style(padding=Padding(color=Color.from_hex("#292524")))
stone_900 = Color.from_hex("#1c1917")
text_stone_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1c1917"))))
text_bg_stone_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1c1917"))))
border_stone_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1c1917"))))
border_bg_stone_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1c1917"))))
margin_stone_900 = Style(margin=Margin(color=Color.from_hex("#1c1917")))
padding_stone_900 = Style(padding=Padding(color=Color.from_hex("#1c1917")))
stone_950 = Color.from_hex("#0c0a09")
text_stone_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0c0a09"))))
text_bg_stone_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0c0a09"))))
border_stone_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0c0a09"))))
border_bg_stone_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0c0a09"))))
margin_stone_950 = Style(margin=Margin(color=Color.from_hex("#0c0a09")))
padding_stone_950 = Style(padding=Padding(color=Color.from_hex("#0c0a09")))

red_50 = Color.from_hex("#fef2f2")
text_red_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fef2f2"))))
text_bg_red_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fef2f2"))))
border_red_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fef2f2"))))
border_bg_red_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fef2f2"))))
margin_red_50 = Style(margin=Margin(color=Color.from_hex("#fef2f2")))
padding_red_50 = Style(padding=Padding(color=Color.from_hex("#fef2f2")))
red_100 = Color.from_hex("#fee2e2")
text_red_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fee2e2"))))
text_bg_red_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fee2e2"))))
border_red_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fee2e2"))))
border_bg_red_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fee2e2"))))
margin_red_100 = Style(margin=Margin(color=Color.from_hex("#fee2e2")))
padding_red_100 = Style(padding=Padding(color=Color.from_hex("#fee2e2")))
red_200 = Color.from_hex("#fecaca")
text_red_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fecaca"))))
text_bg_red_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fecaca"))))
border_red_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fecaca"))))
border_bg_red_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fecaca"))))
margin_red_200 = Style(margin=Margin(color=Color.from_hex("#fecaca")))
padding_red_200 = Style(padding=Padding(color=Color.from_hex("#fecaca")))
red_300 = Color.from_hex("#fca5a5")
text_red_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fca5a5"))))
text_bg_red_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fca5a5"))))
border_red_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fca5a5"))))
border_bg_red_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fca5a5"))))
margin_red_300 = Style(margin=Margin(color=Color.from_hex("#fca5a5")))
padding_red_300 = Style(padding=Padding(color=Color.from_hex("#fca5a5")))
red_400 = Color.from_hex("#f87171")
text_red_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f87171"))))
text_bg_red_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f87171"))))
border_red_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f87171"))))
border_bg_red_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f87171"))))
margin_red_400 = Style(margin=Margin(color=Color.from_hex("#f87171")))
padding_red_400 = Style(padding=Padding(color=Color.from_hex("#f87171")))
red_500 = Color.from_hex("#ef4444")
text_red_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ef4444"))))
text_bg_red_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ef4444"))))
border_red_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ef4444"))))
border_bg_red_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ef4444"))))
margin_red_500 = Style(margin=Margin(color=Color.from_hex("#ef4444")))
padding_red_500 = Style(padding=Padding(color=Color.from_hex("#ef4444")))
red_600 = Color.from_hex("#dc2626")
text_red_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#dc2626"))))
text_bg_red_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#dc2626"))))
border_red_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#dc2626"))))
border_bg_red_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#dc2626"))))
margin_red_600 = Style(margin=Margin(color=Color.from_hex("#dc2626")))
padding_red_600 = Style(padding=Padding(color=Color.from_hex("#dc2626")))
red_700 = Color.from_hex("#b91c1c")
text_red_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#b91c1c"))))
text_bg_red_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#b91c1c"))))
border_red_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#b91c1c"))))
border_bg_red_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#b91c1c"))))
margin_red_700 = Style(margin=Margin(color=Color.from_hex("#b91c1c")))
padding_red_700 = Style(padding=Padding(color=Color.from_hex("#b91c1c")))
red_800 = Color.from_hex("#991b1b")
text_red_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#991b1b"))))
text_bg_red_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#991b1b"))))
border_red_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#991b1b"))))
border_bg_red_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#991b1b"))))
margin_red_800 = Style(margin=Margin(color=Color.from_hex("#991b1b")))
padding_red_800 = Style(padding=Padding(color=Color.from_hex("#991b1b")))
red_900 = Color.from_hex("#7f1d1d")
text_red_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#7f1d1d"))))
text_bg_red_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#7f1d1d"))))
border_red_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#7f1d1d"))))
border_bg_red_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#7f1d1d"))))
margin_red_900 = Style(margin=Margin(color=Color.from_hex("#7f1d1d")))
padding_red_900 = Style(padding=Padding(color=Color.from_hex("#7f1d1d")))
red_950 = Color.from_hex("#450a0a")
text_red_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#450a0a"))))
text_bg_red_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#450a0a"))))
border_red_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#450a0a"))))
border_bg_red_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#450a0a"))))
margin_red_950 = Style(margin=Margin(color=Color.from_hex("#450a0a")))
padding_red_950 = Style(padding=Padding(color=Color.from_hex("#450a0a")))

orange_50 = Color.from_hex("#fff7ed")
text_orange_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fff7ed"))))
text_bg_orange_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fff7ed"))))
border_orange_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fff7ed"))))
border_bg_orange_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fff7ed"))))
margin_orange_50 = Style(margin=Margin(color=Color.from_hex("#fff7ed")))
padding_orange_50 = Style(padding=Padding(color=Color.from_hex("#fff7ed")))
orange_100 = Color.from_hex("#ffedd5")
text_orange_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ffedd5"))))
text_bg_orange_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ffedd5"))))
border_orange_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ffedd5"))))
border_bg_orange_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ffedd5"))))
margin_orange_100 = Style(margin=Margin(color=Color.from_hex("#ffedd5")))
padding_orange_100 = Style(padding=Padding(color=Color.from_hex("#ffedd5")))
orange_200 = Color.from_hex("#fed7aa")
text_orange_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fed7aa"))))
text_bg_orange_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fed7aa"))))
border_orange_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fed7aa"))))
border_bg_orange_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fed7aa"))))
margin_orange_200 = Style(margin=Margin(color=Color.from_hex("#fed7aa")))
padding_orange_200 = Style(padding=Padding(color=Color.from_hex("#fed7aa")))
orange_300 = Color.from_hex("#fdba74")
text_orange_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fdba74"))))
text_bg_orange_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fdba74"))))
border_orange_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fdba74"))))
border_bg_orange_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fdba74"))))
margin_orange_300 = Style(margin=Margin(color=Color.from_hex("#fdba74")))
padding_orange_300 = Style(padding=Padding(color=Color.from_hex("#fdba74")))
orange_400 = Color.from_hex("#fb923c")
text_orange_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fb923c"))))
text_bg_orange_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fb923c"))))
border_orange_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fb923c"))))
border_bg_orange_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fb923c"))))
margin_orange_400 = Style(margin=Margin(color=Color.from_hex("#fb923c")))
padding_orange_400 = Style(padding=Padding(color=Color.from_hex("#fb923c")))
orange_500 = Color.from_hex("#f97316")
text_orange_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f97316"))))
text_bg_orange_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f97316"))))
border_orange_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f97316"))))
border_bg_orange_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f97316"))))
margin_orange_500 = Style(margin=Margin(color=Color.from_hex("#f97316")))
padding_orange_500 = Style(padding=Padding(color=Color.from_hex("#f97316")))
orange_600 = Color.from_hex("#ea580c")
text_orange_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ea580c"))))
text_bg_orange_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ea580c"))))
border_orange_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ea580c"))))
border_bg_orange_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ea580c"))))
margin_orange_600 = Style(margin=Margin(color=Color.from_hex("#ea580c")))
padding_orange_600 = Style(padding=Padding(color=Color.from_hex("#ea580c")))
orange_700 = Color.from_hex("#c2410c")
text_orange_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#c2410c"))))
text_bg_orange_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#c2410c"))))
border_orange_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#c2410c"))))
border_bg_orange_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#c2410c"))))
margin_orange_700 = Style(margin=Margin(color=Color.from_hex("#c2410c")))
padding_orange_700 = Style(padding=Padding(color=Color.from_hex("#c2410c")))
orange_800 = Color.from_hex("#9a3412")
text_orange_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#9a3412"))))
text_bg_orange_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#9a3412"))))
border_orange_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#9a3412"))))
border_bg_orange_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#9a3412"))))
margin_orange_800 = Style(margin=Margin(color=Color.from_hex("#9a3412")))
padding_orange_800 = Style(padding=Padding(color=Color.from_hex("#9a3412")))
orange_900 = Color.from_hex("#7c2d12")
text_orange_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#7c2d12"))))
text_bg_orange_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#7c2d12"))))
border_orange_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#7c2d12"))))
border_bg_orange_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#7c2d12"))))
margin_orange_900 = Style(margin=Margin(color=Color.from_hex("#7c2d12")))
padding_orange_900 = Style(padding=Padding(color=Color.from_hex("#7c2d12")))
orange_950 = Color.from_hex("#431407")
text_orange_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#431407"))))
text_bg_orange_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#431407"))))
border_orange_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#431407"))))
border_bg_orange_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#431407"))))
margin_orange_950 = Style(margin=Margin(color=Color.from_hex("#431407")))
padding_orange_950 = Style(padding=Padding(color=Color.from_hex("#431407")))

amber_50 = Color.from_hex("#fffbeb")
text_amber_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fffbeb"))))
text_bg_amber_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fffbeb"))))
border_amber_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fffbeb"))))
border_bg_amber_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fffbeb"))))
margin_amber_50 = Style(margin=Margin(color=Color.from_hex("#fffbeb")))
padding_amber_50 = Style(padding=Padding(color=Color.from_hex("#fffbeb")))
amber_100 = Color.from_hex("#fef3c7")
text_amber_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fef3c7"))))
text_bg_amber_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fef3c7"))))
border_amber_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fef3c7"))))
border_bg_amber_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fef3c7"))))
margin_amber_100 = Style(margin=Margin(color=Color.from_hex("#fef3c7")))
padding_amber_100 = Style(padding=Padding(color=Color.from_hex("#fef3c7")))
amber_200 = Color.from_hex("#fde68a")
text_amber_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fde68a"))))
text_bg_amber_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fde68a"))))
border_amber_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fde68a"))))
border_bg_amber_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fde68a"))))
margin_amber_200 = Style(margin=Margin(color=Color.from_hex("#fde68a")))
padding_amber_200 = Style(padding=Padding(color=Color.from_hex("#fde68a")))
amber_300 = Color.from_hex("#fcd34d")
text_amber_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fcd34d"))))
text_bg_amber_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fcd34d"))))
border_amber_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fcd34d"))))
border_bg_amber_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fcd34d"))))
margin_amber_300 = Style(margin=Margin(color=Color.from_hex("#fcd34d")))
padding_amber_300 = Style(padding=Padding(color=Color.from_hex("#fcd34d")))
amber_400 = Color.from_hex("#fbbf24")
text_amber_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fbbf24"))))
text_bg_amber_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fbbf24"))))
border_amber_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fbbf24"))))
border_bg_amber_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fbbf24"))))
margin_amber_400 = Style(margin=Margin(color=Color.from_hex("#fbbf24")))
padding_amber_400 = Style(padding=Padding(color=Color.from_hex("#fbbf24")))
amber_500 = Color.from_hex("#f59e0b")
text_amber_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f59e0b"))))
text_bg_amber_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f59e0b"))))
border_amber_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f59e0b"))))
border_bg_amber_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f59e0b"))))
margin_amber_500 = Style(margin=Margin(color=Color.from_hex("#f59e0b")))
padding_amber_500 = Style(padding=Padding(color=Color.from_hex("#f59e0b")))
amber_600 = Color.from_hex("#d97706")
text_amber_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d97706"))))
text_bg_amber_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d97706"))))
border_amber_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d97706"))))
border_bg_amber_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d97706"))))
margin_amber_600 = Style(margin=Margin(color=Color.from_hex("#d97706")))
padding_amber_600 = Style(padding=Padding(color=Color.from_hex("#d97706")))
amber_700 = Color.from_hex("#b45309")
text_amber_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#b45309"))))
text_bg_amber_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#b45309"))))
border_amber_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#b45309"))))
border_bg_amber_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#b45309"))))
margin_amber_700 = Style(margin=Margin(color=Color.from_hex("#b45309")))
padding_amber_700 = Style(padding=Padding(color=Color.from_hex("#b45309")))
amber_800 = Color.from_hex("#92400e")
text_amber_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#92400e"))))
text_bg_amber_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#92400e"))))
border_amber_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#92400e"))))
border_bg_amber_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#92400e"))))
margin_amber_800 = Style(margin=Margin(color=Color.from_hex("#92400e")))
padding_amber_800 = Style(padding=Padding(color=Color.from_hex("#92400e")))
amber_900 = Color.from_hex("#78350f")
text_amber_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#78350f"))))
text_bg_amber_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#78350f"))))
border_amber_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#78350f"))))
border_bg_amber_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#78350f"))))
margin_amber_900 = Style(margin=Margin(color=Color.from_hex("#78350f")))
padding_amber_900 = Style(padding=Padding(color=Color.from_hex("#78350f")))
amber_950 = Color.from_hex("#451a03")
text_amber_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#451a03"))))
text_bg_amber_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#451a03"))))
border_amber_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#451a03"))))
border_bg_amber_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#451a03"))))
margin_amber_950 = Style(margin=Margin(color=Color.from_hex("#451a03")))
padding_amber_950 = Style(padding=Padding(color=Color.from_hex("#451a03")))

yellow_50 = Color.from_hex("#fefce8")
text_yellow_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fefce8"))))
text_bg_yellow_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fefce8"))))
border_yellow_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fefce8"))))
border_bg_yellow_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fefce8"))))
margin_yellow_50 = Style(margin=Margin(color=Color.from_hex("#fefce8")))
padding_yellow_50 = Style(padding=Padding(color=Color.from_hex("#fefce8")))
yellow_100 = Color.from_hex("#fef9c3")
text_yellow_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fef9c3"))))
text_bg_yellow_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fef9c3"))))
border_yellow_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fef9c3"))))
border_bg_yellow_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fef9c3"))))
margin_yellow_100 = Style(margin=Margin(color=Color.from_hex("#fef9c3")))
padding_yellow_100 = Style(padding=Padding(color=Color.from_hex("#fef9c3")))
yellow_200 = Color.from_hex("#fef08a")
text_yellow_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fef08a"))))
text_bg_yellow_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fef08a"))))
border_yellow_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fef08a"))))
border_bg_yellow_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fef08a"))))
margin_yellow_200 = Style(margin=Margin(color=Color.from_hex("#fef08a")))
padding_yellow_200 = Style(padding=Padding(color=Color.from_hex("#fef08a")))
yellow_300 = Color.from_hex("#fde047")
text_yellow_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fde047"))))
text_bg_yellow_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fde047"))))
border_yellow_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fde047"))))
border_bg_yellow_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fde047"))))
margin_yellow_300 = Style(margin=Margin(color=Color.from_hex("#fde047")))
padding_yellow_300 = Style(padding=Padding(color=Color.from_hex("#fde047")))
yellow_400 = Color.from_hex("#facc15")
text_yellow_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#facc15"))))
text_bg_yellow_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#facc15"))))
border_yellow_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#facc15"))))
border_bg_yellow_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#facc15"))))
margin_yellow_400 = Style(margin=Margin(color=Color.from_hex("#facc15")))
padding_yellow_400 = Style(padding=Padding(color=Color.from_hex("#facc15")))
yellow_500 = Color.from_hex("#eab308")
text_yellow_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#eab308"))))
text_bg_yellow_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#eab308"))))
border_yellow_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#eab308"))))
border_bg_yellow_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#eab308"))))
margin_yellow_500 = Style(margin=Margin(color=Color.from_hex("#eab308")))
padding_yellow_500 = Style(padding=Padding(color=Color.from_hex("#eab308")))
yellow_600 = Color.from_hex("#ca8a04")
text_yellow_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ca8a04"))))
text_bg_yellow_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ca8a04"))))
border_yellow_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ca8a04"))))
border_bg_yellow_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ca8a04"))))
margin_yellow_600 = Style(margin=Margin(color=Color.from_hex("#ca8a04")))
padding_yellow_600 = Style(padding=Padding(color=Color.from_hex("#ca8a04")))
yellow_700 = Color.from_hex("#a16207")
text_yellow_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a16207"))))
text_bg_yellow_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a16207"))))
border_yellow_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a16207"))))
border_bg_yellow_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a16207"))))
margin_yellow_700 = Style(margin=Margin(color=Color.from_hex("#a16207")))
padding_yellow_700 = Style(padding=Padding(color=Color.from_hex("#a16207")))
yellow_800 = Color.from_hex("#854d0e")
text_yellow_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#854d0e"))))
text_bg_yellow_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#854d0e"))))
border_yellow_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#854d0e"))))
border_bg_yellow_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#854d0e"))))
margin_yellow_800 = Style(margin=Margin(color=Color.from_hex("#854d0e")))
padding_yellow_800 = Style(padding=Padding(color=Color.from_hex("#854d0e")))
yellow_900 = Color.from_hex("#713f12")
text_yellow_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#713f12"))))
text_bg_yellow_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#713f12"))))
border_yellow_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#713f12"))))
border_bg_yellow_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#713f12"))))
margin_yellow_900 = Style(margin=Margin(color=Color.from_hex("#713f12")))
padding_yellow_900 = Style(padding=Padding(color=Color.from_hex("#713f12")))
yellow_950 = Color.from_hex("#422006")
text_yellow_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#422006"))))
text_bg_yellow_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#422006"))))
border_yellow_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#422006"))))
border_bg_yellow_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#422006"))))
margin_yellow_950 = Style(margin=Margin(color=Color.from_hex("#422006")))
padding_yellow_950 = Style(padding=Padding(color=Color.from_hex("#422006")))

lime_50 = Color.from_hex("#f7fee7")
text_lime_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f7fee7"))))
text_bg_lime_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f7fee7"))))
border_lime_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f7fee7"))))
border_bg_lime_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f7fee7"))))
margin_lime_50 = Style(margin=Margin(color=Color.from_hex("#f7fee7")))
padding_lime_50 = Style(padding=Padding(color=Color.from_hex("#f7fee7")))
lime_100 = Color.from_hex("#ecfccb")
text_lime_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ecfccb"))))
text_bg_lime_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ecfccb"))))
border_lime_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ecfccb"))))
border_bg_lime_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ecfccb"))))
margin_lime_100 = Style(margin=Margin(color=Color.from_hex("#ecfccb")))
padding_lime_100 = Style(padding=Padding(color=Color.from_hex("#ecfccb")))
lime_200 = Color.from_hex("#d9f99d")
text_lime_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d9f99d"))))
text_bg_lime_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d9f99d"))))
border_lime_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d9f99d"))))
border_bg_lime_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d9f99d"))))
margin_lime_200 = Style(margin=Margin(color=Color.from_hex("#d9f99d")))
padding_lime_200 = Style(padding=Padding(color=Color.from_hex("#d9f99d")))
lime_300 = Color.from_hex("#bef264")
text_lime_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#bef264"))))
text_bg_lime_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#bef264"))))
border_lime_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#bef264"))))
border_bg_lime_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#bef264"))))
margin_lime_300 = Style(margin=Margin(color=Color.from_hex("#bef264")))
padding_lime_300 = Style(padding=Padding(color=Color.from_hex("#bef264")))
lime_400 = Color.from_hex("#a3e635")
text_lime_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a3e635"))))
text_bg_lime_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a3e635"))))
border_lime_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a3e635"))))
border_bg_lime_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a3e635"))))
margin_lime_400 = Style(margin=Margin(color=Color.from_hex("#a3e635")))
padding_lime_400 = Style(padding=Padding(color=Color.from_hex("#a3e635")))
lime_500 = Color.from_hex("#84cc16")
text_lime_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#84cc16"))))
text_bg_lime_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#84cc16"))))
border_lime_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#84cc16"))))
border_bg_lime_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#84cc16"))))
margin_lime_500 = Style(margin=Margin(color=Color.from_hex("#84cc16")))
padding_lime_500 = Style(padding=Padding(color=Color.from_hex("#84cc16")))
lime_600 = Color.from_hex("#65a30d")
text_lime_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#65a30d"))))
text_bg_lime_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#65a30d"))))
border_lime_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#65a30d"))))
border_bg_lime_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#65a30d"))))
margin_lime_600 = Style(margin=Margin(color=Color.from_hex("#65a30d")))
padding_lime_600 = Style(padding=Padding(color=Color.from_hex("#65a30d")))
lime_700 = Color.from_hex("#4d7c0f")
text_lime_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4d7c0f"))))
text_bg_lime_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4d7c0f"))))
border_lime_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4d7c0f"))))
border_bg_lime_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4d7c0f"))))
margin_lime_700 = Style(margin=Margin(color=Color.from_hex("#4d7c0f")))
padding_lime_700 = Style(padding=Padding(color=Color.from_hex("#4d7c0f")))
lime_800 = Color.from_hex("#3f6212")
text_lime_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#3f6212"))))
text_bg_lime_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#3f6212"))))
border_lime_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#3f6212"))))
border_bg_lime_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#3f6212"))))
margin_lime_800 = Style(margin=Margin(color=Color.from_hex("#3f6212")))
padding_lime_800 = Style(padding=Padding(color=Color.from_hex("#3f6212")))
lime_900 = Color.from_hex("#365314")
text_lime_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#365314"))))
text_bg_lime_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#365314"))))
border_lime_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#365314"))))
border_bg_lime_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#365314"))))
margin_lime_900 = Style(margin=Margin(color=Color.from_hex("#365314")))
padding_lime_900 = Style(padding=Padding(color=Color.from_hex("#365314")))
lime_950 = Color.from_hex("#1a2e05")
text_lime_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1a2e05"))))
text_bg_lime_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1a2e05"))))
border_lime_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1a2e05"))))
border_bg_lime_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1a2e05"))))
margin_lime_950 = Style(margin=Margin(color=Color.from_hex("#1a2e05")))
padding_lime_950 = Style(padding=Padding(color=Color.from_hex("#1a2e05")))

green_50 = Color.from_hex("#f0fdf4")
text_green_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f0fdf4"))))
text_bg_green_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f0fdf4"))))
border_green_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f0fdf4"))))
border_bg_green_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f0fdf4"))))
margin_green_50 = Style(margin=Margin(color=Color.from_hex("#f0fdf4")))
padding_green_50 = Style(padding=Padding(color=Color.from_hex("#f0fdf4")))
green_100 = Color.from_hex("#dcfce7")
text_green_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#dcfce7"))))
text_bg_green_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#dcfce7"))))
border_green_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#dcfce7"))))
border_bg_green_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#dcfce7"))))
margin_green_100 = Style(margin=Margin(color=Color.from_hex("#dcfce7")))
padding_green_100 = Style(padding=Padding(color=Color.from_hex("#dcfce7")))
green_200 = Color.from_hex("#bbf7d0")
text_green_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#bbf7d0"))))
text_bg_green_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#bbf7d0"))))
border_green_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#bbf7d0"))))
border_bg_green_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#bbf7d0"))))
margin_green_200 = Style(margin=Margin(color=Color.from_hex("#bbf7d0")))
padding_green_200 = Style(padding=Padding(color=Color.from_hex("#bbf7d0")))
green_300 = Color.from_hex("#86efac")
text_green_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#86efac"))))
text_bg_green_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#86efac"))))
border_green_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#86efac"))))
border_bg_green_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#86efac"))))
margin_green_300 = Style(margin=Margin(color=Color.from_hex("#86efac")))
padding_green_300 = Style(padding=Padding(color=Color.from_hex("#86efac")))
green_400 = Color.from_hex("#4ade80")
text_green_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4ade80"))))
text_bg_green_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4ade80"))))
border_green_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4ade80"))))
border_bg_green_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4ade80"))))
margin_green_400 = Style(margin=Margin(color=Color.from_hex("#4ade80")))
padding_green_400 = Style(padding=Padding(color=Color.from_hex("#4ade80")))
green_500 = Color.from_hex("#22c55e")
text_green_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#22c55e"))))
text_bg_green_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#22c55e"))))
border_green_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#22c55e"))))
border_bg_green_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#22c55e"))))
margin_green_500 = Style(margin=Margin(color=Color.from_hex("#22c55e")))
padding_green_500 = Style(padding=Padding(color=Color.from_hex("#22c55e")))
green_600 = Color.from_hex("#16a34a")
text_green_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#16a34a"))))
text_bg_green_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#16a34a"))))
border_green_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#16a34a"))))
border_bg_green_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#16a34a"))))
margin_green_600 = Style(margin=Margin(color=Color.from_hex("#16a34a")))
padding_green_600 = Style(padding=Padding(color=Color.from_hex("#16a34a")))
green_700 = Color.from_hex("#15803d")
text_green_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#15803d"))))
text_bg_green_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#15803d"))))
border_green_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#15803d"))))
border_bg_green_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#15803d"))))
margin_green_700 = Style(margin=Margin(color=Color.from_hex("#15803d")))
padding_green_700 = Style(padding=Padding(color=Color.from_hex("#15803d")))
green_800 = Color.from_hex("#166534")
text_green_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#166534"))))
text_bg_green_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#166534"))))
border_green_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#166534"))))
border_bg_green_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#166534"))))
margin_green_800 = Style(margin=Margin(color=Color.from_hex("#166534")))
padding_green_800 = Style(padding=Padding(color=Color.from_hex("#166534")))
green_900 = Color.from_hex("#14532d")
text_green_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#14532d"))))
text_bg_green_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#14532d"))))
border_green_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#14532d"))))
border_bg_green_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#14532d"))))
margin_green_900 = Style(margin=Margin(color=Color.from_hex("#14532d")))
padding_green_900 = Style(padding=Padding(color=Color.from_hex("#14532d")))
green_950 = Color.from_hex("#052e16")
text_green_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#052e16"))))
text_bg_green_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#052e16"))))
border_green_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#052e16"))))
border_bg_green_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#052e16"))))
margin_green_950 = Style(margin=Margin(color=Color.from_hex("#052e16")))
padding_green_950 = Style(padding=Padding(color=Color.from_hex("#052e16")))

emerald_50 = Color.from_hex("#ecfdf5")
text_emerald_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ecfdf5"))))
text_bg_emerald_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ecfdf5"))))
border_emerald_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ecfdf5"))))
border_bg_emerald_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ecfdf5"))))
margin_emerald_50 = Style(margin=Margin(color=Color.from_hex("#ecfdf5")))
padding_emerald_50 = Style(padding=Padding(color=Color.from_hex("#ecfdf5")))
emerald_100 = Color.from_hex("#d1fae5")
text_emerald_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d1fae5"))))
text_bg_emerald_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d1fae5"))))
border_emerald_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d1fae5"))))
border_bg_emerald_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d1fae5"))))
margin_emerald_100 = Style(margin=Margin(color=Color.from_hex("#d1fae5")))
padding_emerald_100 = Style(padding=Padding(color=Color.from_hex("#d1fae5")))
emerald_200 = Color.from_hex("#a7f3d0")
text_emerald_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a7f3d0"))))
text_bg_emerald_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a7f3d0"))))
border_emerald_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a7f3d0"))))
border_bg_emerald_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a7f3d0"))))
margin_emerald_200 = Style(margin=Margin(color=Color.from_hex("#a7f3d0")))
padding_emerald_200 = Style(padding=Padding(color=Color.from_hex("#a7f3d0")))
emerald_300 = Color.from_hex("#6ee7b7")
text_emerald_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#6ee7b7"))))
text_bg_emerald_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#6ee7b7"))))
border_emerald_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#6ee7b7"))))
border_bg_emerald_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#6ee7b7"))))
margin_emerald_300 = Style(margin=Margin(color=Color.from_hex("#6ee7b7")))
padding_emerald_300 = Style(padding=Padding(color=Color.from_hex("#6ee7b7")))
emerald_400 = Color.from_hex("#34d399")
text_emerald_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#34d399"))))
text_bg_emerald_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#34d399"))))
border_emerald_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#34d399"))))
border_bg_emerald_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#34d399"))))
margin_emerald_400 = Style(margin=Margin(color=Color.from_hex("#34d399")))
padding_emerald_400 = Style(padding=Padding(color=Color.from_hex("#34d399")))
emerald_500 = Color.from_hex("#10b981")
text_emerald_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#10b981"))))
text_bg_emerald_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#10b981"))))
border_emerald_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#10b981"))))
border_bg_emerald_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#10b981"))))
margin_emerald_500 = Style(margin=Margin(color=Color.from_hex("#10b981")))
padding_emerald_500 = Style(padding=Padding(color=Color.from_hex("#10b981")))
emerald_600 = Color.from_hex("#059669")
text_emerald_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#059669"))))
text_bg_emerald_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#059669"))))
border_emerald_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#059669"))))
border_bg_emerald_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#059669"))))
margin_emerald_600 = Style(margin=Margin(color=Color.from_hex("#059669")))
padding_emerald_600 = Style(padding=Padding(color=Color.from_hex("#059669")))
emerald_700 = Color.from_hex("#047857")
text_emerald_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#047857"))))
text_bg_emerald_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#047857"))))
border_emerald_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#047857"))))
border_bg_emerald_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#047857"))))
margin_emerald_700 = Style(margin=Margin(color=Color.from_hex("#047857")))
padding_emerald_700 = Style(padding=Padding(color=Color.from_hex("#047857")))
emerald_800 = Color.from_hex("#065f46")
text_emerald_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#065f46"))))
text_bg_emerald_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#065f46"))))
border_emerald_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#065f46"))))
border_bg_emerald_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#065f46"))))
margin_emerald_800 = Style(margin=Margin(color=Color.from_hex("#065f46")))
padding_emerald_800 = Style(padding=Padding(color=Color.from_hex("#065f46")))
emerald_900 = Color.from_hex("#064e3b")
text_emerald_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#064e3b"))))
text_bg_emerald_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#064e3b"))))
border_emerald_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#064e3b"))))
border_bg_emerald_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#064e3b"))))
margin_emerald_900 = Style(margin=Margin(color=Color.from_hex("#064e3b")))
padding_emerald_900 = Style(padding=Padding(color=Color.from_hex("#064e3b")))
emerald_950 = Color.from_hex("#022c22")
text_emerald_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#022c22"))))
text_bg_emerald_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#022c22"))))
border_emerald_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#022c22"))))
border_bg_emerald_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#022c22"))))
margin_emerald_950 = Style(margin=Margin(color=Color.from_hex("#022c22")))
padding_emerald_950 = Style(padding=Padding(color=Color.from_hex("#022c22")))

teal_50 = Color.from_hex("#f0fdfa")
text_teal_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f0fdfa"))))
text_bg_teal_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f0fdfa"))))
border_teal_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f0fdfa"))))
border_bg_teal_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f0fdfa"))))
margin_teal_50 = Style(margin=Margin(color=Color.from_hex("#f0fdfa")))
padding_teal_50 = Style(padding=Padding(color=Color.from_hex("#f0fdfa")))
teal_100 = Color.from_hex("#ccfbf1")
text_teal_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ccfbf1"))))
text_bg_teal_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ccfbf1"))))
border_teal_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ccfbf1"))))
border_bg_teal_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ccfbf1"))))
margin_teal_100 = Style(margin=Margin(color=Color.from_hex("#ccfbf1")))
padding_teal_100 = Style(padding=Padding(color=Color.from_hex("#ccfbf1")))
teal_200 = Color.from_hex("#99f6e4")
text_teal_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#99f6e4"))))
text_bg_teal_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#99f6e4"))))
border_teal_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#99f6e4"))))
border_bg_teal_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#99f6e4"))))
margin_teal_200 = Style(margin=Margin(color=Color.from_hex("#99f6e4")))
padding_teal_200 = Style(padding=Padding(color=Color.from_hex("#99f6e4")))
teal_300 = Color.from_hex("#5eead4")
text_teal_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#5eead4"))))
text_bg_teal_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#5eead4"))))
border_teal_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#5eead4"))))
border_bg_teal_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#5eead4"))))
margin_teal_300 = Style(margin=Margin(color=Color.from_hex("#5eead4")))
padding_teal_300 = Style(padding=Padding(color=Color.from_hex("#5eead4")))
teal_400 = Color.from_hex("#2dd4bf")
text_teal_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#2dd4bf"))))
text_bg_teal_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#2dd4bf"))))
border_teal_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#2dd4bf"))))
border_bg_teal_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#2dd4bf"))))
margin_teal_400 = Style(margin=Margin(color=Color.from_hex("#2dd4bf")))
padding_teal_400 = Style(padding=Padding(color=Color.from_hex("#2dd4bf")))
teal_500 = Color.from_hex("#14b8a6")
text_teal_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#14b8a6"))))
text_bg_teal_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#14b8a6"))))
border_teal_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#14b8a6"))))
border_bg_teal_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#14b8a6"))))
margin_teal_500 = Style(margin=Margin(color=Color.from_hex("#14b8a6")))
padding_teal_500 = Style(padding=Padding(color=Color.from_hex("#14b8a6")))
teal_600 = Color.from_hex("#0d9488")
text_teal_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0d9488"))))
text_bg_teal_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0d9488"))))
border_teal_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0d9488"))))
border_bg_teal_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0d9488"))))
margin_teal_600 = Style(margin=Margin(color=Color.from_hex("#0d9488")))
padding_teal_600 = Style(padding=Padding(color=Color.from_hex("#0d9488")))
teal_700 = Color.from_hex("#0f766e")
text_teal_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0f766e"))))
text_bg_teal_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0f766e"))))
border_teal_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0f766e"))))
border_bg_teal_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0f766e"))))
margin_teal_700 = Style(margin=Margin(color=Color.from_hex("#0f766e")))
padding_teal_700 = Style(padding=Padding(color=Color.from_hex("#0f766e")))
teal_800 = Color.from_hex("#115e59")
text_teal_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#115e59"))))
text_bg_teal_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#115e59"))))
border_teal_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#115e59"))))
border_bg_teal_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#115e59"))))
margin_teal_800 = Style(margin=Margin(color=Color.from_hex("#115e59")))
padding_teal_800 = Style(padding=Padding(color=Color.from_hex("#115e59")))
teal_900 = Color.from_hex("#134e4a")
text_teal_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#134e4a"))))
text_bg_teal_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#134e4a"))))
border_teal_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#134e4a"))))
border_bg_teal_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#134e4a"))))
margin_teal_900 = Style(margin=Margin(color=Color.from_hex("#134e4a")))
padding_teal_900 = Style(padding=Padding(color=Color.from_hex("#134e4a")))
teal_950 = Color.from_hex("#042f2e")
text_teal_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#042f2e"))))
text_bg_teal_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#042f2e"))))
border_teal_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#042f2e"))))
border_bg_teal_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#042f2e"))))
margin_teal_950 = Style(margin=Margin(color=Color.from_hex("#042f2e")))
padding_teal_950 = Style(padding=Padding(color=Color.from_hex("#042f2e")))

cyan_50 = Color.from_hex("#ecfeff")
text_cyan_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ecfeff"))))
text_bg_cyan_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ecfeff"))))
border_cyan_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ecfeff"))))
border_bg_cyan_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ecfeff"))))
margin_cyan_50 = Style(margin=Margin(color=Color.from_hex("#ecfeff")))
padding_cyan_50 = Style(padding=Padding(color=Color.from_hex("#ecfeff")))
cyan_100 = Color.from_hex("#cffafe")
text_cyan_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#cffafe"))))
text_bg_cyan_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#cffafe"))))
border_cyan_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#cffafe"))))
border_bg_cyan_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#cffafe"))))
margin_cyan_100 = Style(margin=Margin(color=Color.from_hex("#cffafe")))
padding_cyan_100 = Style(padding=Padding(color=Color.from_hex("#cffafe")))
cyan_200 = Color.from_hex("#a5f3fc")
text_cyan_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a5f3fc"))))
text_bg_cyan_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a5f3fc"))))
border_cyan_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a5f3fc"))))
border_bg_cyan_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a5f3fc"))))
margin_cyan_200 = Style(margin=Margin(color=Color.from_hex("#a5f3fc")))
padding_cyan_200 = Style(padding=Padding(color=Color.from_hex("#a5f3fc")))
cyan_300 = Color.from_hex("#67e8f9")
text_cyan_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#67e8f9"))))
text_bg_cyan_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#67e8f9"))))
border_cyan_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#67e8f9"))))
border_bg_cyan_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#67e8f9"))))
margin_cyan_300 = Style(margin=Margin(color=Color.from_hex("#67e8f9")))
padding_cyan_300 = Style(padding=Padding(color=Color.from_hex("#67e8f9")))
cyan_400 = Color.from_hex("#22d3ee")
text_cyan_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#22d3ee"))))
text_bg_cyan_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#22d3ee"))))
border_cyan_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#22d3ee"))))
border_bg_cyan_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#22d3ee"))))
margin_cyan_400 = Style(margin=Margin(color=Color.from_hex("#22d3ee")))
padding_cyan_400 = Style(padding=Padding(color=Color.from_hex("#22d3ee")))
cyan_500 = Color.from_hex("#06b6d4")
text_cyan_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#06b6d4"))))
text_bg_cyan_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#06b6d4"))))
border_cyan_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#06b6d4"))))
border_bg_cyan_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#06b6d4"))))
margin_cyan_500 = Style(margin=Margin(color=Color.from_hex("#06b6d4")))
padding_cyan_500 = Style(padding=Padding(color=Color.from_hex("#06b6d4")))
cyan_600 = Color.from_hex("#0891b2")
text_cyan_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0891b2"))))
text_bg_cyan_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0891b2"))))
border_cyan_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0891b2"))))
border_bg_cyan_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0891b2"))))
margin_cyan_600 = Style(margin=Margin(color=Color.from_hex("#0891b2")))
padding_cyan_600 = Style(padding=Padding(color=Color.from_hex("#0891b2")))
cyan_700 = Color.from_hex("#0e7490")
text_cyan_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0e7490"))))
text_bg_cyan_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0e7490"))))
border_cyan_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0e7490"))))
border_bg_cyan_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0e7490"))))
margin_cyan_700 = Style(margin=Margin(color=Color.from_hex("#0e7490")))
padding_cyan_700 = Style(padding=Padding(color=Color.from_hex("#0e7490")))
cyan_800 = Color.from_hex("#155e75")
text_cyan_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#155e75"))))
text_bg_cyan_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#155e75"))))
border_cyan_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#155e75"))))
border_bg_cyan_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#155e75"))))
margin_cyan_800 = Style(margin=Margin(color=Color.from_hex("#155e75")))
padding_cyan_800 = Style(padding=Padding(color=Color.from_hex("#155e75")))
cyan_900 = Color.from_hex("#164e63")
text_cyan_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#164e63"))))
text_bg_cyan_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#164e63"))))
border_cyan_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#164e63"))))
border_bg_cyan_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#164e63"))))
margin_cyan_900 = Style(margin=Margin(color=Color.from_hex("#164e63")))
padding_cyan_900 = Style(padding=Padding(color=Color.from_hex("#164e63")))
cyan_950 = Color.from_hex("#083344")
text_cyan_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#083344"))))
text_bg_cyan_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#083344"))))
border_cyan_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#083344"))))
border_bg_cyan_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#083344"))))
margin_cyan_950 = Style(margin=Margin(color=Color.from_hex("#083344")))
padding_cyan_950 = Style(padding=Padding(color=Color.from_hex("#083344")))

sky_50 = Color.from_hex("#f0f9ff")
text_sky_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f0f9ff"))))
text_bg_sky_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f0f9ff"))))
border_sky_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f0f9ff"))))
border_bg_sky_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f0f9ff"))))
margin_sky_50 = Style(margin=Margin(color=Color.from_hex("#f0f9ff")))
padding_sky_50 = Style(padding=Padding(color=Color.from_hex("#f0f9ff")))
sky_100 = Color.from_hex("#e0f2fe")
text_sky_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e0f2fe"))))
text_bg_sky_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e0f2fe"))))
border_sky_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e0f2fe"))))
border_bg_sky_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e0f2fe"))))
margin_sky_100 = Style(margin=Margin(color=Color.from_hex("#e0f2fe")))
padding_sky_100 = Style(padding=Padding(color=Color.from_hex("#e0f2fe")))
sky_200 = Color.from_hex("#bae6fd")
text_sky_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#bae6fd"))))
text_bg_sky_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#bae6fd"))))
border_sky_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#bae6fd"))))
border_bg_sky_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#bae6fd"))))
margin_sky_200 = Style(margin=Margin(color=Color.from_hex("#bae6fd")))
padding_sky_200 = Style(padding=Padding(color=Color.from_hex("#bae6fd")))
sky_300 = Color.from_hex("#7dd3fc")
text_sky_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#7dd3fc"))))
text_bg_sky_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#7dd3fc"))))
border_sky_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#7dd3fc"))))
border_bg_sky_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#7dd3fc"))))
margin_sky_300 = Style(margin=Margin(color=Color.from_hex("#7dd3fc")))
padding_sky_300 = Style(padding=Padding(color=Color.from_hex("#7dd3fc")))
sky_400 = Color.from_hex("#38bdf8")
text_sky_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#38bdf8"))))
text_bg_sky_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#38bdf8"))))
border_sky_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#38bdf8"))))
border_bg_sky_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#38bdf8"))))
margin_sky_400 = Style(margin=Margin(color=Color.from_hex("#38bdf8")))
padding_sky_400 = Style(padding=Padding(color=Color.from_hex("#38bdf8")))
sky_500 = Color.from_hex("#0ea5e9")
text_sky_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0ea5e9"))))
text_bg_sky_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0ea5e9"))))
border_sky_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0ea5e9"))))
border_bg_sky_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0ea5e9"))))
margin_sky_500 = Style(margin=Margin(color=Color.from_hex("#0ea5e9")))
padding_sky_500 = Style(padding=Padding(color=Color.from_hex("#0ea5e9")))
sky_600 = Color.from_hex("#0284c7")
text_sky_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0284c7"))))
text_bg_sky_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0284c7"))))
border_sky_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0284c7"))))
border_bg_sky_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0284c7"))))
margin_sky_600 = Style(margin=Margin(color=Color.from_hex("#0284c7")))
padding_sky_600 = Style(padding=Padding(color=Color.from_hex("#0284c7")))
sky_700 = Color.from_hex("#0369a1")
text_sky_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0369a1"))))
text_bg_sky_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0369a1"))))
border_sky_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0369a1"))))
border_bg_sky_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0369a1"))))
margin_sky_700 = Style(margin=Margin(color=Color.from_hex("#0369a1")))
padding_sky_700 = Style(padding=Padding(color=Color.from_hex("#0369a1")))
sky_800 = Color.from_hex("#075985")
text_sky_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#075985"))))
text_bg_sky_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#075985"))))
border_sky_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#075985"))))
border_bg_sky_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#075985"))))
margin_sky_800 = Style(margin=Margin(color=Color.from_hex("#075985")))
padding_sky_800 = Style(padding=Padding(color=Color.from_hex("#075985")))
sky_900 = Color.from_hex("#0c4a6e")
text_sky_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#0c4a6e"))))
text_bg_sky_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#0c4a6e"))))
border_sky_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#0c4a6e"))))
border_bg_sky_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#0c4a6e"))))
margin_sky_900 = Style(margin=Margin(color=Color.from_hex("#0c4a6e")))
padding_sky_900 = Style(padding=Padding(color=Color.from_hex("#0c4a6e")))
sky_950 = Color.from_hex("#082f49")
text_sky_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#082f49"))))
text_bg_sky_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#082f49"))))
border_sky_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#082f49"))))
border_bg_sky_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#082f49"))))
margin_sky_950 = Style(margin=Margin(color=Color.from_hex("#082f49")))
padding_sky_950 = Style(padding=Padding(color=Color.from_hex("#082f49")))

blue_50 = Color.from_hex("#eff6ff")
text_blue_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#eff6ff"))))
text_bg_blue_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#eff6ff"))))
border_blue_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#eff6ff"))))
border_bg_blue_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#eff6ff"))))
margin_blue_50 = Style(margin=Margin(color=Color.from_hex("#eff6ff")))
padding_blue_50 = Style(padding=Padding(color=Color.from_hex("#eff6ff")))
blue_100 = Color.from_hex("#dbeafe")
text_blue_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#dbeafe"))))
text_bg_blue_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#dbeafe"))))
border_blue_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#dbeafe"))))
border_bg_blue_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#dbeafe"))))
margin_blue_100 = Style(margin=Margin(color=Color.from_hex("#dbeafe")))
padding_blue_100 = Style(padding=Padding(color=Color.from_hex("#dbeafe")))
blue_200 = Color.from_hex("#bfdbfe")
text_blue_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#bfdbfe"))))
text_bg_blue_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#bfdbfe"))))
border_blue_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#bfdbfe"))))
border_bg_blue_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#bfdbfe"))))
margin_blue_200 = Style(margin=Margin(color=Color.from_hex("#bfdbfe")))
padding_blue_200 = Style(padding=Padding(color=Color.from_hex("#bfdbfe")))
blue_300 = Color.from_hex("#93c5fd")
text_blue_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#93c5fd"))))
text_bg_blue_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#93c5fd"))))
border_blue_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#93c5fd"))))
border_bg_blue_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#93c5fd"))))
margin_blue_300 = Style(margin=Margin(color=Color.from_hex("#93c5fd")))
padding_blue_300 = Style(padding=Padding(color=Color.from_hex("#93c5fd")))
blue_400 = Color.from_hex("#60a5fa")
text_blue_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#60a5fa"))))
text_bg_blue_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#60a5fa"))))
border_blue_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#60a5fa"))))
border_bg_blue_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#60a5fa"))))
margin_blue_400 = Style(margin=Margin(color=Color.from_hex("#60a5fa")))
padding_blue_400 = Style(padding=Padding(color=Color.from_hex("#60a5fa")))
blue_500 = Color.from_hex("#3b82f6")
text_blue_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#3b82f6"))))
text_bg_blue_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#3b82f6"))))
border_blue_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#3b82f6"))))
border_bg_blue_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#3b82f6"))))
margin_blue_500 = Style(margin=Margin(color=Color.from_hex("#3b82f6")))
padding_blue_500 = Style(padding=Padding(color=Color.from_hex("#3b82f6")))
blue_600 = Color.from_hex("#2563eb")
text_blue_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#2563eb"))))
text_bg_blue_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#2563eb"))))
border_blue_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#2563eb"))))
border_bg_blue_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#2563eb"))))
margin_blue_600 = Style(margin=Margin(color=Color.from_hex("#2563eb")))
padding_blue_600 = Style(padding=Padding(color=Color.from_hex("#2563eb")))
blue_700 = Color.from_hex("#1d4ed8")
text_blue_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1d4ed8"))))
text_bg_blue_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1d4ed8"))))
border_blue_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1d4ed8"))))
border_bg_blue_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1d4ed8"))))
margin_blue_700 = Style(margin=Margin(color=Color.from_hex("#1d4ed8")))
padding_blue_700 = Style(padding=Padding(color=Color.from_hex("#1d4ed8")))
blue_800 = Color.from_hex("#1e40af")
text_blue_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1e40af"))))
text_bg_blue_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1e40af"))))
border_blue_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1e40af"))))
border_bg_blue_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1e40af"))))
margin_blue_800 = Style(margin=Margin(color=Color.from_hex("#1e40af")))
padding_blue_800 = Style(padding=Padding(color=Color.from_hex("#1e40af")))
blue_900 = Color.from_hex("#1e3a8a")
text_blue_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1e3a8a"))))
text_bg_blue_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1e3a8a"))))
border_blue_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1e3a8a"))))
border_bg_blue_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1e3a8a"))))
margin_blue_900 = Style(margin=Margin(color=Color.from_hex("#1e3a8a")))
padding_blue_900 = Style(padding=Padding(color=Color.from_hex("#1e3a8a")))
blue_950 = Color.from_hex("#172554")
text_blue_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#172554"))))
text_bg_blue_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#172554"))))
border_blue_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#172554"))))
border_bg_blue_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#172554"))))
margin_blue_950 = Style(margin=Margin(color=Color.from_hex("#172554")))
padding_blue_950 = Style(padding=Padding(color=Color.from_hex("#172554")))

indigo_50 = Color.from_hex("#eef2ff")
text_indigo_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#eef2ff"))))
text_bg_indigo_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#eef2ff"))))
border_indigo_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#eef2ff"))))
border_bg_indigo_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#eef2ff"))))
margin_indigo_50 = Style(margin=Margin(color=Color.from_hex("#eef2ff")))
padding_indigo_50 = Style(padding=Padding(color=Color.from_hex("#eef2ff")))
indigo_100 = Color.from_hex("#e0e7ff")
text_indigo_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e0e7ff"))))
text_bg_indigo_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e0e7ff"))))
border_indigo_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e0e7ff"))))
border_bg_indigo_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e0e7ff"))))
margin_indigo_100 = Style(margin=Margin(color=Color.from_hex("#e0e7ff")))
padding_indigo_100 = Style(padding=Padding(color=Color.from_hex("#e0e7ff")))
indigo_200 = Color.from_hex("#c7d2fe")
text_indigo_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#c7d2fe"))))
text_bg_indigo_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#c7d2fe"))))
border_indigo_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#c7d2fe"))))
border_bg_indigo_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#c7d2fe"))))
margin_indigo_200 = Style(margin=Margin(color=Color.from_hex("#c7d2fe")))
padding_indigo_200 = Style(padding=Padding(color=Color.from_hex("#c7d2fe")))
indigo_300 = Color.from_hex("#a5b4fc")
text_indigo_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a5b4fc"))))
text_bg_indigo_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a5b4fc"))))
border_indigo_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a5b4fc"))))
border_bg_indigo_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a5b4fc"))))
margin_indigo_300 = Style(margin=Margin(color=Color.from_hex("#a5b4fc")))
padding_indigo_300 = Style(padding=Padding(color=Color.from_hex("#a5b4fc")))
indigo_400 = Color.from_hex("#818cf8")
text_indigo_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#818cf8"))))
text_bg_indigo_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#818cf8"))))
border_indigo_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#818cf8"))))
border_bg_indigo_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#818cf8"))))
margin_indigo_400 = Style(margin=Margin(color=Color.from_hex("#818cf8")))
padding_indigo_400 = Style(padding=Padding(color=Color.from_hex("#818cf8")))
indigo_500 = Color.from_hex("#6366f1")
text_indigo_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#6366f1"))))
text_bg_indigo_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#6366f1"))))
border_indigo_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#6366f1"))))
border_bg_indigo_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#6366f1"))))
margin_indigo_500 = Style(margin=Margin(color=Color.from_hex("#6366f1")))
padding_indigo_500 = Style(padding=Padding(color=Color.from_hex("#6366f1")))
indigo_600 = Color.from_hex("#4f46e5")
text_indigo_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4f46e5"))))
text_bg_indigo_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4f46e5"))))
border_indigo_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4f46e5"))))
border_bg_indigo_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4f46e5"))))
margin_indigo_600 = Style(margin=Margin(color=Color.from_hex("#4f46e5")))
padding_indigo_600 = Style(padding=Padding(color=Color.from_hex("#4f46e5")))
indigo_700 = Color.from_hex("#4338ca")
text_indigo_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4338ca"))))
text_bg_indigo_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4338ca"))))
border_indigo_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4338ca"))))
border_bg_indigo_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4338ca"))))
margin_indigo_700 = Style(margin=Margin(color=Color.from_hex("#4338ca")))
padding_indigo_700 = Style(padding=Padding(color=Color.from_hex("#4338ca")))
indigo_800 = Color.from_hex("#3730a3")
text_indigo_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#3730a3"))))
text_bg_indigo_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#3730a3"))))
border_indigo_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#3730a3"))))
border_bg_indigo_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#3730a3"))))
margin_indigo_800 = Style(margin=Margin(color=Color.from_hex("#3730a3")))
padding_indigo_800 = Style(padding=Padding(color=Color.from_hex("#3730a3")))
indigo_900 = Color.from_hex("#312e81")
text_indigo_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#312e81"))))
text_bg_indigo_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#312e81"))))
border_indigo_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#312e81"))))
border_bg_indigo_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#312e81"))))
margin_indigo_900 = Style(margin=Margin(color=Color.from_hex("#312e81")))
padding_indigo_900 = Style(padding=Padding(color=Color.from_hex("#312e81")))
indigo_950 = Color.from_hex("#1e1b4b")
text_indigo_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#1e1b4b"))))
text_bg_indigo_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#1e1b4b"))))
border_indigo_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#1e1b4b"))))
border_bg_indigo_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#1e1b4b"))))
margin_indigo_950 = Style(margin=Margin(color=Color.from_hex("#1e1b4b")))
padding_indigo_950 = Style(padding=Padding(color=Color.from_hex("#1e1b4b")))

violet_50 = Color.from_hex("#f5f3ff")
text_violet_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f5f3ff"))))
text_bg_violet_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f5f3ff"))))
border_violet_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f5f3ff"))))
border_bg_violet_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f5f3ff"))))
margin_violet_50 = Style(margin=Margin(color=Color.from_hex("#f5f3ff")))
padding_violet_50 = Style(padding=Padding(color=Color.from_hex("#f5f3ff")))
violet_100 = Color.from_hex("#ede9fe")
text_violet_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ede9fe"))))
text_bg_violet_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ede9fe"))))
border_violet_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ede9fe"))))
border_bg_violet_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ede9fe"))))
margin_violet_100 = Style(margin=Margin(color=Color.from_hex("#ede9fe")))
padding_violet_100 = Style(padding=Padding(color=Color.from_hex("#ede9fe")))
violet_200 = Color.from_hex("#ddd6fe")
text_violet_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ddd6fe"))))
text_bg_violet_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ddd6fe"))))
border_violet_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ddd6fe"))))
border_bg_violet_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ddd6fe"))))
margin_violet_200 = Style(margin=Margin(color=Color.from_hex("#ddd6fe")))
padding_violet_200 = Style(padding=Padding(color=Color.from_hex("#ddd6fe")))
violet_300 = Color.from_hex("#c4b5fd")
text_violet_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#c4b5fd"))))
text_bg_violet_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#c4b5fd"))))
border_violet_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#c4b5fd"))))
border_bg_violet_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#c4b5fd"))))
margin_violet_300 = Style(margin=Margin(color=Color.from_hex("#c4b5fd")))
padding_violet_300 = Style(padding=Padding(color=Color.from_hex("#c4b5fd")))
violet_400 = Color.from_hex("#a78bfa")
text_violet_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a78bfa"))))
text_bg_violet_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a78bfa"))))
border_violet_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a78bfa"))))
border_bg_violet_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a78bfa"))))
margin_violet_400 = Style(margin=Margin(color=Color.from_hex("#a78bfa")))
padding_violet_400 = Style(padding=Padding(color=Color.from_hex("#a78bfa")))
violet_500 = Color.from_hex("#8b5cf6")
text_violet_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#8b5cf6"))))
text_bg_violet_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#8b5cf6"))))
border_violet_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#8b5cf6"))))
border_bg_violet_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#8b5cf6"))))
margin_violet_500 = Style(margin=Margin(color=Color.from_hex("#8b5cf6")))
padding_violet_500 = Style(padding=Padding(color=Color.from_hex("#8b5cf6")))
violet_600 = Color.from_hex("#7c3aed")
text_violet_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#7c3aed"))))
text_bg_violet_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#7c3aed"))))
border_violet_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#7c3aed"))))
border_bg_violet_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#7c3aed"))))
margin_violet_600 = Style(margin=Margin(color=Color.from_hex("#7c3aed")))
padding_violet_600 = Style(padding=Padding(color=Color.from_hex("#7c3aed")))
violet_700 = Color.from_hex("#6d28d9")
text_violet_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#6d28d9"))))
text_bg_violet_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#6d28d9"))))
border_violet_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#6d28d9"))))
border_bg_violet_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#6d28d9"))))
margin_violet_700 = Style(margin=Margin(color=Color.from_hex("#6d28d9")))
padding_violet_700 = Style(padding=Padding(color=Color.from_hex("#6d28d9")))
violet_800 = Color.from_hex("#5b21b6")
text_violet_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#5b21b6"))))
text_bg_violet_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#5b21b6"))))
border_violet_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#5b21b6"))))
border_bg_violet_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#5b21b6"))))
margin_violet_800 = Style(margin=Margin(color=Color.from_hex("#5b21b6")))
padding_violet_800 = Style(padding=Padding(color=Color.from_hex("#5b21b6")))
violet_900 = Color.from_hex("#4c1d95")
text_violet_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4c1d95"))))
text_bg_violet_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4c1d95"))))
border_violet_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4c1d95"))))
border_bg_violet_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4c1d95"))))
margin_violet_900 = Style(margin=Margin(color=Color.from_hex("#4c1d95")))
padding_violet_900 = Style(padding=Padding(color=Color.from_hex("#4c1d95")))
violet_950 = Color.from_hex("#2e1065")
text_violet_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#2e1065"))))
text_bg_violet_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#2e1065"))))
border_violet_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#2e1065"))))
border_bg_violet_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#2e1065"))))
margin_violet_950 = Style(margin=Margin(color=Color.from_hex("#2e1065")))
padding_violet_950 = Style(padding=Padding(color=Color.from_hex("#2e1065")))

purple_50 = Color.from_hex("#faf5ff")
text_purple_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#faf5ff"))))
text_bg_purple_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#faf5ff"))))
border_purple_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#faf5ff"))))
border_bg_purple_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#faf5ff"))))
margin_purple_50 = Style(margin=Margin(color=Color.from_hex("#faf5ff")))
padding_purple_50 = Style(padding=Padding(color=Color.from_hex("#faf5ff")))
purple_100 = Color.from_hex("#f3e8ff")
text_purple_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f3e8ff"))))
text_bg_purple_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f3e8ff"))))
border_purple_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f3e8ff"))))
border_bg_purple_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f3e8ff"))))
margin_purple_100 = Style(margin=Margin(color=Color.from_hex("#f3e8ff")))
padding_purple_100 = Style(padding=Padding(color=Color.from_hex("#f3e8ff")))
purple_200 = Color.from_hex("#e9d5ff")
text_purple_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e9d5ff"))))
text_bg_purple_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e9d5ff"))))
border_purple_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e9d5ff"))))
border_bg_purple_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e9d5ff"))))
margin_purple_200 = Style(margin=Margin(color=Color.from_hex("#e9d5ff")))
padding_purple_200 = Style(padding=Padding(color=Color.from_hex("#e9d5ff")))
purple_300 = Color.from_hex("#d8b4fe")
text_purple_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d8b4fe"))))
text_bg_purple_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d8b4fe"))))
border_purple_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d8b4fe"))))
border_bg_purple_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d8b4fe"))))
margin_purple_300 = Style(margin=Margin(color=Color.from_hex("#d8b4fe")))
padding_purple_300 = Style(padding=Padding(color=Color.from_hex("#d8b4fe")))
purple_400 = Color.from_hex("#c084fc")
text_purple_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#c084fc"))))
text_bg_purple_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#c084fc"))))
border_purple_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#c084fc"))))
border_bg_purple_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#c084fc"))))
margin_purple_400 = Style(margin=Margin(color=Color.from_hex("#c084fc")))
padding_purple_400 = Style(padding=Padding(color=Color.from_hex("#c084fc")))
purple_500 = Color.from_hex("#a855f7")
text_purple_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a855f7"))))
text_bg_purple_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a855f7"))))
border_purple_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a855f7"))))
border_bg_purple_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a855f7"))))
margin_purple_500 = Style(margin=Margin(color=Color.from_hex("#a855f7")))
padding_purple_500 = Style(padding=Padding(color=Color.from_hex("#a855f7")))
purple_600 = Color.from_hex("#9333ea")
text_purple_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#9333ea"))))
text_bg_purple_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#9333ea"))))
border_purple_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#9333ea"))))
border_bg_purple_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#9333ea"))))
margin_purple_600 = Style(margin=Margin(color=Color.from_hex("#9333ea")))
padding_purple_600 = Style(padding=Padding(color=Color.from_hex("#9333ea")))
purple_700 = Color.from_hex("#7e22ce")
text_purple_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#7e22ce"))))
text_bg_purple_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#7e22ce"))))
border_purple_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#7e22ce"))))
border_bg_purple_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#7e22ce"))))
margin_purple_700 = Style(margin=Margin(color=Color.from_hex("#7e22ce")))
padding_purple_700 = Style(padding=Padding(color=Color.from_hex("#7e22ce")))
purple_800 = Color.from_hex("#6b21a8")
text_purple_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#6b21a8"))))
text_bg_purple_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#6b21a8"))))
border_purple_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#6b21a8"))))
border_bg_purple_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#6b21a8"))))
margin_purple_800 = Style(margin=Margin(color=Color.from_hex("#6b21a8")))
padding_purple_800 = Style(padding=Padding(color=Color.from_hex("#6b21a8")))
purple_900 = Color.from_hex("#581c87")
text_purple_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#581c87"))))
text_bg_purple_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#581c87"))))
border_purple_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#581c87"))))
border_bg_purple_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#581c87"))))
margin_purple_900 = Style(margin=Margin(color=Color.from_hex("#581c87")))
padding_purple_900 = Style(padding=Padding(color=Color.from_hex("#581c87")))
purple_950 = Color.from_hex("#3b0764")
text_purple_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#3b0764"))))
text_bg_purple_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#3b0764"))))
border_purple_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#3b0764"))))
border_bg_purple_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#3b0764"))))
margin_purple_950 = Style(margin=Margin(color=Color.from_hex("#3b0764")))
padding_purple_950 = Style(padding=Padding(color=Color.from_hex("#3b0764")))

fuchsia_50 = Color.from_hex("#fdf4ff")
text_fuchsia_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fdf4ff"))))
text_bg_fuchsia_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fdf4ff"))))
border_fuchsia_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fdf4ff"))))
border_bg_fuchsia_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fdf4ff"))))
margin_fuchsia_50 = Style(margin=Margin(color=Color.from_hex("#fdf4ff")))
padding_fuchsia_50 = Style(padding=Padding(color=Color.from_hex("#fdf4ff")))
fuchsia_100 = Color.from_hex("#fae8ff")
text_fuchsia_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fae8ff"))))
text_bg_fuchsia_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fae8ff"))))
border_fuchsia_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fae8ff"))))
border_bg_fuchsia_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fae8ff"))))
margin_fuchsia_100 = Style(margin=Margin(color=Color.from_hex("#fae8ff")))
padding_fuchsia_100 = Style(padding=Padding(color=Color.from_hex("#fae8ff")))
fuchsia_200 = Color.from_hex("#f5d0fe")
text_fuchsia_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f5d0fe"))))
text_bg_fuchsia_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f5d0fe"))))
border_fuchsia_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f5d0fe"))))
border_bg_fuchsia_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f5d0fe"))))
margin_fuchsia_200 = Style(margin=Margin(color=Color.from_hex("#f5d0fe")))
padding_fuchsia_200 = Style(padding=Padding(color=Color.from_hex("#f5d0fe")))
fuchsia_300 = Color.from_hex("#f0abfc")
text_fuchsia_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f0abfc"))))
text_bg_fuchsia_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f0abfc"))))
border_fuchsia_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f0abfc"))))
border_bg_fuchsia_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f0abfc"))))
margin_fuchsia_300 = Style(margin=Margin(color=Color.from_hex("#f0abfc")))
padding_fuchsia_300 = Style(padding=Padding(color=Color.from_hex("#f0abfc")))
fuchsia_400 = Color.from_hex("#e879f9")
text_fuchsia_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e879f9"))))
text_bg_fuchsia_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e879f9"))))
border_fuchsia_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e879f9"))))
border_bg_fuchsia_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e879f9"))))
margin_fuchsia_400 = Style(margin=Margin(color=Color.from_hex("#e879f9")))
padding_fuchsia_400 = Style(padding=Padding(color=Color.from_hex("#e879f9")))
fuchsia_500 = Color.from_hex("#d946ef")
text_fuchsia_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#d946ef"))))
text_bg_fuchsia_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#d946ef"))))
border_fuchsia_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#d946ef"))))
border_bg_fuchsia_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#d946ef"))))
margin_fuchsia_500 = Style(margin=Margin(color=Color.from_hex("#d946ef")))
padding_fuchsia_500 = Style(padding=Padding(color=Color.from_hex("#d946ef")))
fuchsia_600 = Color.from_hex("#c026d3")
text_fuchsia_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#c026d3"))))
text_bg_fuchsia_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#c026d3"))))
border_fuchsia_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#c026d3"))))
border_bg_fuchsia_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#c026d3"))))
margin_fuchsia_600 = Style(margin=Margin(color=Color.from_hex("#c026d3")))
padding_fuchsia_600 = Style(padding=Padding(color=Color.from_hex("#c026d3")))
fuchsia_700 = Color.from_hex("#a21caf")
text_fuchsia_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#a21caf"))))
text_bg_fuchsia_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#a21caf"))))
border_fuchsia_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#a21caf"))))
border_bg_fuchsia_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#a21caf"))))
margin_fuchsia_700 = Style(margin=Margin(color=Color.from_hex("#a21caf")))
padding_fuchsia_700 = Style(padding=Padding(color=Color.from_hex("#a21caf")))
fuchsia_800 = Color.from_hex("#86198f")
text_fuchsia_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#86198f"))))
text_bg_fuchsia_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#86198f"))))
border_fuchsia_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#86198f"))))
border_bg_fuchsia_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#86198f"))))
margin_fuchsia_800 = Style(margin=Margin(color=Color.from_hex("#86198f")))
padding_fuchsia_800 = Style(padding=Padding(color=Color.from_hex("#86198f")))
fuchsia_900 = Color.from_hex("#701a75")
text_fuchsia_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#701a75"))))
text_bg_fuchsia_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#701a75"))))
border_fuchsia_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#701a75"))))
border_bg_fuchsia_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#701a75"))))
margin_fuchsia_900 = Style(margin=Margin(color=Color.from_hex("#701a75")))
padding_fuchsia_900 = Style(padding=Padding(color=Color.from_hex("#701a75")))
fuchsia_950 = Color.from_hex("#4a044e")
text_fuchsia_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4a044e"))))
text_bg_fuchsia_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4a044e"))))
border_fuchsia_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4a044e"))))
border_bg_fuchsia_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4a044e"))))
margin_fuchsia_950 = Style(margin=Margin(color=Color.from_hex("#4a044e")))
padding_fuchsia_950 = Style(padding=Padding(color=Color.from_hex("#4a044e")))

pink_50 = Color.from_hex("#fdf2f8")
text_pink_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fdf2f8"))))
text_bg_pink_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fdf2f8"))))
border_pink_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fdf2f8"))))
border_bg_pink_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fdf2f8"))))
margin_pink_50 = Style(margin=Margin(color=Color.from_hex("#fdf2f8")))
padding_pink_50 = Style(padding=Padding(color=Color.from_hex("#fdf2f8")))
pink_100 = Color.from_hex("#fce7f3")
text_pink_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fce7f3"))))
text_bg_pink_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fce7f3"))))
border_pink_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fce7f3"))))
border_bg_pink_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fce7f3"))))
margin_pink_100 = Style(margin=Margin(color=Color.from_hex("#fce7f3")))
padding_pink_100 = Style(padding=Padding(color=Color.from_hex("#fce7f3")))
pink_200 = Color.from_hex("#fbcfe8")
text_pink_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fbcfe8"))))
text_bg_pink_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fbcfe8"))))
border_pink_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fbcfe8"))))
border_bg_pink_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fbcfe8"))))
margin_pink_200 = Style(margin=Margin(color=Color.from_hex("#fbcfe8")))
padding_pink_200 = Style(padding=Padding(color=Color.from_hex("#fbcfe8")))
pink_300 = Color.from_hex("#f9a8d4")
text_pink_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f9a8d4"))))
text_bg_pink_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f9a8d4"))))
border_pink_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f9a8d4"))))
border_bg_pink_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f9a8d4"))))
margin_pink_300 = Style(margin=Margin(color=Color.from_hex("#f9a8d4")))
padding_pink_300 = Style(padding=Padding(color=Color.from_hex("#f9a8d4")))
pink_400 = Color.from_hex("#f472b6")
text_pink_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f472b6"))))
text_bg_pink_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f472b6"))))
border_pink_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f472b6"))))
border_bg_pink_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f472b6"))))
margin_pink_400 = Style(margin=Margin(color=Color.from_hex("#f472b6")))
padding_pink_400 = Style(padding=Padding(color=Color.from_hex("#f472b6")))
pink_500 = Color.from_hex("#ec4899")
text_pink_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ec4899"))))
text_bg_pink_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ec4899"))))
border_pink_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ec4899"))))
border_bg_pink_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ec4899"))))
margin_pink_500 = Style(margin=Margin(color=Color.from_hex("#ec4899")))
padding_pink_500 = Style(padding=Padding(color=Color.from_hex("#ec4899")))
pink_600 = Color.from_hex("#db2777")
text_pink_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#db2777"))))
text_bg_pink_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#db2777"))))
border_pink_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#db2777"))))
border_bg_pink_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#db2777"))))
margin_pink_600 = Style(margin=Margin(color=Color.from_hex("#db2777")))
padding_pink_600 = Style(padding=Padding(color=Color.from_hex("#db2777")))
pink_700 = Color.from_hex("#be185d")
text_pink_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#be185d"))))
text_bg_pink_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#be185d"))))
border_pink_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#be185d"))))
border_bg_pink_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#be185d"))))
margin_pink_700 = Style(margin=Margin(color=Color.from_hex("#be185d")))
padding_pink_700 = Style(padding=Padding(color=Color.from_hex("#be185d")))
pink_800 = Color.from_hex("#9d174d")
text_pink_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#9d174d"))))
text_bg_pink_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#9d174d"))))
border_pink_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#9d174d"))))
border_bg_pink_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#9d174d"))))
margin_pink_800 = Style(margin=Margin(color=Color.from_hex("#9d174d")))
padding_pink_800 = Style(padding=Padding(color=Color.from_hex("#9d174d")))
pink_900 = Color.from_hex("#831843")
text_pink_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#831843"))))
text_bg_pink_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#831843"))))
border_pink_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#831843"))))
border_bg_pink_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#831843"))))
margin_pink_900 = Style(margin=Margin(color=Color.from_hex("#831843")))
padding_pink_900 = Style(padding=Padding(color=Color.from_hex("#831843")))
pink_950 = Color.from_hex("#500724")
text_pink_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#500724"))))
text_bg_pink_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#500724"))))
border_pink_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#500724"))))
border_bg_pink_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#500724"))))
margin_pink_950 = Style(margin=Margin(color=Color.from_hex("#500724")))
padding_pink_950 = Style(padding=Padding(color=Color.from_hex("#500724")))

rose_50 = Color.from_hex("#fff1f2")
text_rose_50 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fff1f2"))))
text_bg_rose_50 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fff1f2"))))
border_rose_50 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fff1f2"))))
border_bg_rose_50 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fff1f2"))))
margin_rose_50 = Style(margin=Margin(color=Color.from_hex("#fff1f2")))
padding_rose_50 = Style(padding=Padding(color=Color.from_hex("#fff1f2")))
rose_100 = Color.from_hex("#ffe4e6")
text_rose_100 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#ffe4e6"))))
text_bg_rose_100 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#ffe4e6"))))
border_rose_100 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#ffe4e6"))))
border_bg_rose_100 = Style(border=Border(style=CellStyle(background=Color.from_hex("#ffe4e6"))))
margin_rose_100 = Style(margin=Margin(color=Color.from_hex("#ffe4e6")))
padding_rose_100 = Style(padding=Padding(color=Color.from_hex("#ffe4e6")))
rose_200 = Color.from_hex("#fecdd3")
text_rose_200 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fecdd3"))))
text_bg_rose_200 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fecdd3"))))
border_rose_200 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fecdd3"))))
border_bg_rose_200 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fecdd3"))))
margin_rose_200 = Style(margin=Margin(color=Color.from_hex("#fecdd3")))
padding_rose_200 = Style(padding=Padding(color=Color.from_hex("#fecdd3")))
rose_300 = Color.from_hex("#fda4af")
text_rose_300 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fda4af"))))
text_bg_rose_300 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fda4af"))))
border_rose_300 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fda4af"))))
border_bg_rose_300 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fda4af"))))
margin_rose_300 = Style(margin=Margin(color=Color.from_hex("#fda4af")))
padding_rose_300 = Style(padding=Padding(color=Color.from_hex("#fda4af")))
rose_400 = Color.from_hex("#fb7185")
text_rose_400 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#fb7185"))))
text_bg_rose_400 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#fb7185"))))
border_rose_400 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#fb7185"))))
border_bg_rose_400 = Style(border=Border(style=CellStyle(background=Color.from_hex("#fb7185"))))
margin_rose_400 = Style(margin=Margin(color=Color.from_hex("#fb7185")))
padding_rose_400 = Style(padding=Padding(color=Color.from_hex("#fb7185")))
rose_500 = Color.from_hex("#f43f5e")
text_rose_500 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#f43f5e"))))
text_bg_rose_500 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#f43f5e"))))
border_rose_500 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#f43f5e"))))
border_bg_rose_500 = Style(border=Border(style=CellStyle(background=Color.from_hex("#f43f5e"))))
margin_rose_500 = Style(margin=Margin(color=Color.from_hex("#f43f5e")))
padding_rose_500 = Style(padding=Padding(color=Color.from_hex("#f43f5e")))
rose_600 = Color.from_hex("#e11d48")
text_rose_600 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#e11d48"))))
text_bg_rose_600 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#e11d48"))))
border_rose_600 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#e11d48"))))
border_bg_rose_600 = Style(border=Border(style=CellStyle(background=Color.from_hex("#e11d48"))))
margin_rose_600 = Style(margin=Margin(color=Color.from_hex("#e11d48")))
padding_rose_600 = Style(padding=Padding(color=Color.from_hex("#e11d48")))
rose_700 = Color.from_hex("#be123c")
text_rose_700 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#be123c"))))
text_bg_rose_700 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#be123c"))))
border_rose_700 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#be123c"))))
border_bg_rose_700 = Style(border=Border(style=CellStyle(background=Color.from_hex("#be123c"))))
margin_rose_700 = Style(margin=Margin(color=Color.from_hex("#be123c")))
padding_rose_700 = Style(padding=Padding(color=Color.from_hex("#be123c")))
rose_800 = Color.from_hex("#9f1239")
text_rose_800 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#9f1239"))))
text_bg_rose_800 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#9f1239"))))
border_rose_800 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#9f1239"))))
border_bg_rose_800 = Style(border=Border(style=CellStyle(background=Color.from_hex("#9f1239"))))
margin_rose_800 = Style(margin=Margin(color=Color.from_hex("#9f1239")))
padding_rose_800 = Style(padding=Padding(color=Color.from_hex("#9f1239")))
rose_900 = Color.from_hex("#881337")
text_rose_900 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#881337"))))
text_bg_rose_900 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#881337"))))
border_rose_900 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#881337"))))
border_bg_rose_900 = Style(border=Border(style=CellStyle(background=Color.from_hex("#881337"))))
margin_rose_900 = Style(margin=Margin(color=Color.from_hex("#881337")))
padding_rose_900 = Style(padding=Padding(color=Color.from_hex("#881337")))
rose_950 = Color.from_hex("#4c0519")
text_rose_950 = Style(typography=Typography(style=CellStyle(foreground=Color.from_hex("#4c0519"))))
text_bg_rose_950 = Style(typography=Typography(style=CellStyle(background=Color.from_hex("#4c0519"))))
border_rose_950 = Style(border=Border(style=CellStyle(foreground=Color.from_hex("#4c0519"))))
border_bg_rose_950 = Style(border=Border(style=CellStyle(background=Color.from_hex("#4c0519"))))
margin_rose_950 = Style(margin=Margin(color=Color.from_hex("#4c0519")))
padding_rose_950 = Style(padding=Padding(color=Color.from_hex("#4c0519")))

row = Style(layout=Flex(direction="row"))
col = Style(layout=Flex(direction="column"))

justify_children_start = Style(layout=Flex(justify_children="start"))
justify_children_center = Style(layout=Flex(justify_children="center"))
justify_children_end = Style(layout=Flex(justify_children="end"))
justify_children_space_between = Style(layout=Flex(justify_children="space-between"))
justify_children_space_around = Style(layout=Flex(justify_children="space-around"))
justify_children_space_evenly = Style(layout=Flex(justify_children="space-evenly"))

align_children_start = Style(layout=Flex(align_children="start"))
align_children_center = Style(layout=Flex(align_children="center"))
align_children_end = Style(layout=Flex(align_children="end"))
align_children_stretch = Style(layout=Flex(align_children="stretch"))

align_self_none = Style(layout=Flex(align_self="none"))
align_self_start = Style(layout=Flex(align_self="start"))
align_self_center = Style(layout=Flex(align_self="center"))
align_self_end = Style(layout=Flex(align_self="end"))
align_self_stretch = Style(layout=Flex(align_self="stretch"))

weight_none = Style(layout=Flex(weight=None))
weight_1 = Style(layout=Flex(weight=1))
weight_2 = Style(layout=Flex(weight=2))
weight_3 = Style(layout=Flex(weight=3))
weight_4 = Style(layout=Flex(weight=4))
weight_5 = Style(layout=Flex(weight=5))
weight_6 = Style(layout=Flex(weight=6))
weight_7 = Style(layout=Flex(weight=7))
weight_8 = Style(layout=Flex(weight=8))

border_none = Style(border=None)
border_light = Style(border=Border(kind=BorderKind.Light))
border_lightrounded = Style(border=Border(kind=BorderKind.LightRounded))
border_lightangled = Style(border=Border(kind=BorderKind.LightAngled))
border_heavy = Style(border=Border(kind=BorderKind.Heavy))
border_double = Style(border=Border(kind=BorderKind.Double))
border_thick = Style(border=Border(kind=BorderKind.Thick))
border_mcgugan = Style(border=Border(kind=BorderKind.McGugan))
border_lightshade = Style(border=Border(kind=BorderKind.LightShade))
border_mediumshade = Style(border=Border(kind=BorderKind.MediumShade))
border_heavyshade = Style(border=Border(kind=BorderKind.HeavyShade))
border_star = Style(border=Border(kind=BorderKind.Star))

border_top = Style(border=Border(edges=frozenset((BorderEdge.Top,))))
border_bottom = Style(border=Border(edges=frozenset((BorderEdge.Bottom,))))
border_left = Style(border=Border(edges=frozenset((BorderEdge.Left,))))
border_right = Style(border=Border(edges=frozenset((BorderEdge.Right,))))
border_top_bottom = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Bottom))))
border_top_left = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Left))))
border_top_right = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Right))))
border_bottom_left = Style(border=Border(edges=frozenset((BorderEdge.Bottom, BorderEdge.Left))))
border_bottom_right = Style(border=Border(edges=frozenset((BorderEdge.Bottom, BorderEdge.Right))))
border_left_right = Style(border=Border(edges=frozenset((BorderEdge.Left, BorderEdge.Right))))
border_top_bottom_left = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Bottom, BorderEdge.Left))))
border_top_bottom_right = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Bottom, BorderEdge.Right))))
border_top_left_right = Style(border=Border(edges=frozenset((BorderEdge.Top, BorderEdge.Left, BorderEdge.Right))))
border_bottom_left_right = Style(border=Border(edges=frozenset((BorderEdge.Bottom, BorderEdge.Left, BorderEdge.Right))))

border_contract_0 = Style(border=Border(contract=0))
border_contract_1 = Style(border=Border(contract=1))
border_contract_2 = Style(border=Border(contract=2))
border_contract_3 = Style(border=Border(contract=3))
border_contract_4 = Style(border=Border(contract=4))
border_contract_5 = Style(border=Border(contract=5))
border_contract_6 = Style(border=Border(contract=6))
border_contract_7 = Style(border=Border(contract=7))
border_contract_8 = Style(border=Border(contract=8))

pad_top_0 = Style(padding=Padding(top=0))
pad_top_1 = Style(padding=Padding(top=1))
pad_top_2 = Style(padding=Padding(top=2))
pad_top_3 = Style(padding=Padding(top=3))
pad_top_4 = Style(padding=Padding(top=4))
pad_top_5 = Style(padding=Padding(top=5))
pad_top_6 = Style(padding=Padding(top=6))
pad_top_7 = Style(padding=Padding(top=7))
pad_top_8 = Style(padding=Padding(top=8))

pad_bottom_0 = Style(padding=Padding(bottom=0))
pad_bottom_1 = Style(padding=Padding(bottom=1))
pad_bottom_2 = Style(padding=Padding(bottom=2))
pad_bottom_3 = Style(padding=Padding(bottom=3))
pad_bottom_4 = Style(padding=Padding(bottom=4))
pad_bottom_5 = Style(padding=Padding(bottom=5))
pad_bottom_6 = Style(padding=Padding(bottom=6))
pad_bottom_7 = Style(padding=Padding(bottom=7))
pad_bottom_8 = Style(padding=Padding(bottom=8))

pad_left_0 = Style(padding=Padding(left=0))
pad_left_1 = Style(padding=Padding(left=1))
pad_left_2 = Style(padding=Padding(left=2))
pad_left_3 = Style(padding=Padding(left=3))
pad_left_4 = Style(padding=Padding(left=4))
pad_left_5 = Style(padding=Padding(left=5))
pad_left_6 = Style(padding=Padding(left=6))
pad_left_7 = Style(padding=Padding(left=7))
pad_left_8 = Style(padding=Padding(left=8))

pad_right_0 = Style(padding=Padding(right=0))
pad_right_1 = Style(padding=Padding(right=1))
pad_right_2 = Style(padding=Padding(right=2))
pad_right_3 = Style(padding=Padding(right=3))
pad_right_4 = Style(padding=Padding(right=4))
pad_right_5 = Style(padding=Padding(right=5))
pad_right_6 = Style(padding=Padding(right=6))
pad_right_7 = Style(padding=Padding(right=7))
pad_right_8 = Style(padding=Padding(right=8))

pad_x_0 = Style(padding=Padding(left=0, right=0))
pad_x_1 = Style(padding=Padding(left=1, right=1))
pad_x_2 = Style(padding=Padding(left=2, right=2))
pad_x_3 = Style(padding=Padding(left=3, right=3))
pad_x_4 = Style(padding=Padding(left=4, right=4))
pad_x_5 = Style(padding=Padding(left=5, right=5))
pad_x_6 = Style(padding=Padding(left=6, right=6))
pad_x_7 = Style(padding=Padding(left=7, right=7))
pad_x_8 = Style(padding=Padding(left=8, right=8))

pad_y_0 = Style(padding=Padding(top=0, bottom=0))
pad_y_1 = Style(padding=Padding(top=1, bottom=1))
pad_y_2 = Style(padding=Padding(top=2, bottom=2))
pad_y_3 = Style(padding=Padding(top=3, bottom=3))
pad_y_4 = Style(padding=Padding(top=4, bottom=4))
pad_y_5 = Style(padding=Padding(top=5, bottom=5))
pad_y_6 = Style(padding=Padding(top=6, bottom=6))
pad_y_7 = Style(padding=Padding(top=7, bottom=7))
pad_y_8 = Style(padding=Padding(top=8, bottom=8))

pad_0 = Style(padding=Padding(top=0, bottom=0, left=0, right=0))
pad_1 = Style(padding=Padding(top=1, bottom=1, left=1, right=1))
pad_2 = Style(padding=Padding(top=2, bottom=2, left=2, right=2))
pad_3 = Style(padding=Padding(top=3, bottom=3, left=3, right=3))
pad_4 = Style(padding=Padding(top=4, bottom=4, left=4, right=4))
pad_5 = Style(padding=Padding(top=5, bottom=5, left=5, right=5))
pad_6 = Style(padding=Padding(top=6, bottom=6, left=6, right=6))
pad_7 = Style(padding=Padding(top=7, bottom=7, left=7, right=7))
pad_8 = Style(padding=Padding(top=8, bottom=8, left=8, right=8))

margin_top_0 = Style(margin=Margin(top=0))
margin_top_1 = Style(margin=Margin(top=1))
margin_top_2 = Style(margin=Margin(top=2))
margin_top_3 = Style(margin=Margin(top=3))
margin_top_4 = Style(margin=Margin(top=4))
margin_top_5 = Style(margin=Margin(top=5))
margin_top_6 = Style(margin=Margin(top=6))
margin_top_7 = Style(margin=Margin(top=7))
margin_top_8 = Style(margin=Margin(top=8))

margin_bottom_0 = Style(margin=Margin(bottom=0))
margin_bottom_1 = Style(margin=Margin(bottom=1))
margin_bottom_2 = Style(margin=Margin(bottom=2))
margin_bottom_3 = Style(margin=Margin(bottom=3))
margin_bottom_4 = Style(margin=Margin(bottom=4))
margin_bottom_5 = Style(margin=Margin(bottom=5))
margin_bottom_6 = Style(margin=Margin(bottom=6))
margin_bottom_7 = Style(margin=Margin(bottom=7))
margin_bottom_8 = Style(margin=Margin(bottom=8))

margin_left_0 = Style(margin=Margin(left=0))
margin_left_1 = Style(margin=Margin(left=1))
margin_left_2 = Style(margin=Margin(left=2))
margin_left_3 = Style(margin=Margin(left=3))
margin_left_4 = Style(margin=Margin(left=4))
margin_left_5 = Style(margin=Margin(left=5))
margin_left_6 = Style(margin=Margin(left=6))
margin_left_7 = Style(margin=Margin(left=7))
margin_left_8 = Style(margin=Margin(left=8))

margin_right_0 = Style(margin=Margin(right=0))
margin_right_1 = Style(margin=Margin(right=1))
margin_right_2 = Style(margin=Margin(right=2))
margin_right_3 = Style(margin=Margin(right=3))
margin_right_4 = Style(margin=Margin(right=4))
margin_right_5 = Style(margin=Margin(right=5))
margin_right_6 = Style(margin=Margin(right=6))
margin_right_7 = Style(margin=Margin(right=7))
margin_right_8 = Style(margin=Margin(right=8))

margin_x_0 = Style(margin=Margin(left=0, right=0))
margin_x_1 = Style(margin=Margin(left=1, right=1))
margin_x_2 = Style(margin=Margin(left=2, right=2))
margin_x_3 = Style(margin=Margin(left=3, right=3))
margin_x_4 = Style(margin=Margin(left=4, right=4))
margin_x_5 = Style(margin=Margin(left=5, right=5))
margin_x_6 = Style(margin=Margin(left=6, right=6))
margin_x_7 = Style(margin=Margin(left=7, right=7))
margin_x_8 = Style(margin=Margin(left=8, right=8))

margin_y_0 = Style(margin=Margin(top=0, bottom=0))
margin_y_1 = Style(margin=Margin(top=1, bottom=1))
margin_y_2 = Style(margin=Margin(top=2, bottom=2))
margin_y_3 = Style(margin=Margin(top=3, bottom=3))
margin_y_4 = Style(margin=Margin(top=4, bottom=4))
margin_y_5 = Style(margin=Margin(top=5, bottom=5))
margin_y_6 = Style(margin=Margin(top=6, bottom=6))
margin_y_7 = Style(margin=Margin(top=7, bottom=7))
margin_y_8 = Style(margin=Margin(top=8, bottom=8))

margin_0 = Style(margin=Margin(top=0, bottom=0, left=0, right=0))
margin_1 = Style(margin=Margin(top=1, bottom=1, left=1, right=1))
margin_2 = Style(margin=Margin(top=2, bottom=2, left=2, right=2))
margin_3 = Style(margin=Margin(top=3, bottom=3, left=3, right=3))
margin_4 = Style(margin=Margin(top=4, bottom=4, left=4, right=4))
margin_5 = Style(margin=Margin(top=5, bottom=5, left=5, right=5))
margin_6 = Style(margin=Margin(top=6, bottom=6, left=6, right=6))
margin_7 = Style(margin=Margin(top=7, bottom=7, left=7, right=7))
margin_8 = Style(margin=Margin(top=8, bottom=8, left=8, right=8))

gap_children_0 = Style(layout=Flex(gap_children=0))
gap_children_1 = Style(layout=Flex(gap_children=1))
gap_children_2 = Style(layout=Flex(gap_children=2))
gap_children_3 = Style(layout=Flex(gap_children=3))
gap_children_4 = Style(layout=Flex(gap_children=4))
gap_children_5 = Style(layout=Flex(gap_children=5))
gap_children_6 = Style(layout=Flex(gap_children=6))
gap_children_7 = Style(layout=Flex(gap_children=7))
gap_children_8 = Style(layout=Flex(gap_children=8))

text_justify_left = Style(typography=Typography(justify="left"))
text_justify_center = Style(typography=Typography(justify="center"))
text_justify_right = Style(typography=Typography(justify="right"))

# Stop generated


def toggle(b: bool) -> bool:
    return not b
